##############################################################################
#
# File: include.mk
# Version: 4.0.2
# Date: 11/03/09
#
##############################################################################
# Copyright (c) 2009, HART Communication Foundation, All Rights Reserved
##############################################################################
#
# Description: This is an additional makefile included with the DD-IDE. 
#
# It currently contains everything needed to rebuild all the DDs supplied 
# with the DD-IDE. There are 3 targets of key interest in this makefile.
#
# This file controls which tokenizer is building the DD
#
#
# This file maintains the dependencies between the encoded DD (.fm6) and 
# source file (.ddl) for the Standard and Generic DDs
# 
##############################################################################

##############################################################################
#
#     PLEASE DO NOT EDIT THIS FILE AS IT MAY AFFECT PROGRAM OPERATION!!!
#
##############################################################################

##############################################################################
#
# TOKENIZER = 5, old rev 5 tokenizer (original DDL prior to 2005)
# TOKENIZER = 6, version 6 tokenizer (supports Enhanced DDL)
# TOKENIZER = 8, version 8 tokenizer (supports Enhanced DDL, UTF8, TIME_VALUE)

ifndef TOKENIZER
TOKENIZER=6
endif

ifeq ($(TOKENIZER),5)
DDT=hcftok32.exe -d /hcf/ddl/library/standard$(DC_EXT)
OPTION = -q HR
DD_EXT = .fms
DC_EXT = .dct
endif

ifeq ($(TOKENIZER),6)
DDT=ddt.exe -d /hcf/ddl/library/standard$(DC_EXT)
OPTION = -q HR
DD_EXT = .fm6
DC_EXT = .dct
endif

ifeq ($(TOKENIZER),8)
DDT=ddt8.exe -d /hcf/ddl/library/standard$(DC_EXT)
OPTION = 
DD_EXT = .fm8
DC_EXT = .dc8
endif 

ifndef TARGET
TARGET=Undefined_Target
endif

ifndef DD
DD=Undefined_FM?
endif

.PHONY : all clean 

##############################################################################
#
# Next are a bunch of macros (make calls them variables) that make life
# easier when decelring all our rules
#

STANDARD = $(RELEASE)\000000

##############################################################################
#
# Common tables MACROS
#

TABLES = $(STANDARD)\0001
TABLE6_1 = $(TABLES)\0601$(DD_EXT)
TABLE7_1 = $(TABLES)\0701$(DD_EXT)
TABLE8_1 = $(TABLES)\0801$(DD_EXT)
TABLE9_2 = $(TABLES)\0902$(DD_EXT)
TABL10_1 = $(TABLES)\0a01$(DD_EXT)
TABL11_1 = $(TABLES)\0b01$(DD_EXT)
TABL13_1 = $(TABLES)\0d01$(DD_EXT)
TABL14_1 = $(TABLES)\0e01$(DD_EXT)
TABL15_1 = $(TABLES)\0f01$(DD_EXT)
TABL16_2 = $(TABLES)\1002$(DD_EXT)
TABL17_4 = $(TABLES)\1104$(DD_EXT)
TABL20_1 = $(TABLES)\1401$(DD_EXT)

ALL_TABLES = $(TABLE6_1) $(TABLE7_1) $(TABLE8_1) $(TABLE9_2) $(TABL10_1) $(TABL11_1) $(TABL13_1) $(TABL14_1) $(TABL15_1) $(TABL16_2) $(TABL17_4) $(TABL20_1)   

##############################################################################
#
# Universal command MACROS
#

UNIVERSAL = $(STANDARD)\0002
UNIV5	= $(UNIVERSAL)\0501$(DD_EXT)
UNIV4	= $(UNIVERSAL)\0401$(DD_EXT)
UNIV4_2	= $(UNIVERSAL)\0402$(DD_EXT)
UNIV3	= $(UNIVERSAL)\0301$(DD_EXT)
UNIV3_2	= $(UNIVERSAL)\0302$(DD_EXT)
UNIV5_2	= $(UNIVERSAL)\0502$(DD_EXT)
UNIV6	= $(UNIVERSAL)\0601$(DD_EXT)
UNIV7	= $(UNIVERSAL)\0700$(DD_EXT)

ALL_UNIVERSAL = $(UNIV5) $(UNIV4) $(UNIV4_2) $(UNIV3) $(UNIV3_2) $(UNIV5_2) $(UNIV6) $(UNIV7)

##############################################################################
#
# Common practice command MACROS
#

COMMON_PRACTICE	= $(STANDARD)\0003
CMN3_2	= $(COMMON_PRACTICE)\0302$(DD_EXT)
CMN4_2	= $(COMMON_PRACTICE)\0402$(DD_EXT)
CMN5_2	= $(COMMON_PRACTICE)\0502$(DD_EXT)
CMN6_2	= $(COMMON_PRACTICE)\0602$(DD_EXT)
CMN7_2	= $(COMMON_PRACTICE)\0702$(DD_EXT)
CMN7_3	= $(COMMON_PRACTICE)\0703$(DD_EXT)
COMMON3	= $(COMMON_PRACTICE)\0301$(DD_EXT)
COMMON4	= $(COMMON_PRACTICE)\0401$(DD_EXT)
COMMON5	= $(COMMON_PRACTICE)\0501$(DD_EXT)
COMMON6	= $(COMMON_PRACTICE)\0601$(DD_EXT)
COMMON7	= $(COMMON_PRACTICE)\0701$(DD_EXT)
COMMON8	= $(COMMON_PRACTICE)\0801$(DD_EXT)
COMMON9	= $(COMMON_PRACTICE)\0900$(DD_EXT)

ALL_COMMON_PRACTICE = $(CMN3_2) $(CMN4_2) $(CMN5_2) $(CMN6_2) $(CMN7_2) $(CMN7_3) $(COMMON3) $(COMMON4) \
	$(COMMON5) $(COMMON6) $(COMMON7) $(COMMON8) $(COMMON9)

##############################################################################
#
# Wireless command MACROS
#

WIRELESS = $(STANDARD)\0018\0100$(DD_EXT)

##############################################################################
#
# Moore manufacturer specific interop dd MACROS
#

MOORE = $(STANDARD)\0013
MOOR_STD = $(MOORE)\0101$(DD_EXT)
MOORSTD2 = $(MOORE)\0102$(DD_EXT)
MOORSTD3 = $(MOORE)\0103$(DD_EXT)
MOORSTD4 = $(MOORE)\0104$(DD_EXT)
ALL_MOORE = $(MOOR_STD) $(MOORSTD2) $(MOORSTD3) $(MOORSTD4)

##############################################################################
#
# Draeger manufacturer specific interop dd MACROS
#

DRAEGER = $(STANDARD)\0015
P2CMN_5 = $(DRAEGER)\0105$(DD_EXT)
P2CMN_6	= $(DRAEGER)\0106$(DD_EXT)
P2CMN_7	= $(DRAEGER)\0107$(DD_EXT)
ALL_DRAEGER = $(P2CMN_5) $(P2CMN_6) $(P2CMN_7)

##############################################################################
#
# Rosemount manufacturer specific interop dd MACROS
#

RMTFLOW = $(STANDARD)\0011
RFLOW3_3 = $(RMTFLOW)\0303$(DD_EXT)
RFLOW4_3 = $(RMTFLOW)\0403$(DD_EXT)
RFLOW5_3 = $(RMTFLOW)\0503$(DD_EXT)
RFLOW5_2 = $(RMTFLOW)\0502$(DD_EXT)
ALL_RMTFLOW = $(RFLOW3_3) $(RFLOW4_3) $(RFLOW5_3) $(RFLOW5_2)

RMTPRES = $(STANDARD)\0012
RPRES1_1 = $(RMTPRES)\0101$(DD_EXT)
RPRES4_1 = $(RMTPRES)\0401$(DD_EXT)
RPRES5_1 = $(RMTPRES)\0501$(DD_EXT)
RPRES5_2 = $(RMTPRES)\0502$(DD_EXT)
RPRES5_4 = $(RMTPRES)\0504$(DD_EXT)
RPRES6_2 = $(RMTPRES)\0602$(DD_EXT)
RPRES7_2 = $(RMTPRES)\0702$(DD_EXT)
RPRES7_3 = $(RMTPRES)\0703$(DD_EXT)
RPRES7_4 = $(RMTPRES)\0704$(DD_EXT)
ALL_RMTPRES = $(RPRES1_1) $(RPRES4_1) $(RPRES5_1) $(RPRES5_2) $(RPRES5_4) $(RPRES6_2) $(RPRES7_2) $(RPRES7_3) \
              $(RPRES7_4)

##############################################################################
#
# Other interop MACROS
#

PV = $(STANDARD)\0016\0101$(DD_EXT)
MENU = $(STANDARD)\0010\0101$(DD_EXT)
SIEPRES = $(STANDARD)\0014\0101$(DD_EXT)
PRES_UNIVERSAL = $(STANDARD)\0007\0101$(DD_EXT)
PRES_UNIVERSAL_2 = $(STANDARD)\0007\0201$(DD_EXT)
PRES_COMMON = $(STANDARD)\0008\0101$(DD_EXT)
PRES_COMMON_2 = $(STANDARD)\0008\0201$(DD_EXT)
MUNGE = $(STANDARD)\0063\6363$(DD_EXT)
SDC = $(RELEASE)\0000f9\0083\0100$(DD_EXT)

##############################################################################
#
# Device Families MACROS
#

##############################################################################
#
# The generic DDs (they are used when a dd for the device cannot be found).
#

UN3XMTR   = $(RELEASE)\000026\0080\0305$(DD_EXT)
UN4XMTR   = $(RELEASE)\000026\0080\0405$(DD_EXT)
UNIVXMTR  = $(RELEASE)\000026\0080\0505$(DD_EXT)
UNIV6XMTR = $(RELEASE)\000026\0080\0602$(DD_EXT)
UNIV7XMTR = $(RELEASE)\000026\0080\0702$(DD_EXT)
GENERIC_HOST = $(UN3XMTR) $(UN4XMTR) $(UNIVXMTR) $(UNIV6XMTR) $(UNIV7XMTR)

##############################################################################
#
# This macro is the compiled list of all the standard and generic files
#
# Note: The use of the continuation lines using the backslash ( \ )
#

STDS = $(MUNGE) $(SDC) $(ALL_TABLES) $(ALL_UNIVERSAL) $(ALL_COMMON_PRACTICE) $(WIRELESS) $(PV) $(SIEPRES) $(MENU) $(ALL_RMTFLOW) \
	$(ALL_RMTPRES) $(ALL_MOORE) $(PRES_UNIVERSAL) $(PRES_UNIVERSAL_2) $(PRES_COMMON) $(PRES_COMMON_2) \
	$(ALL_DRAEGER) $(ALL_FAMILIES) $(GENERIC_HOST)



