//==============================================================================
//
// MACTek - Wireless HART Adapter DD
//
//  MACTek Corporation All rights reserved. Proprietary and Confidential
// 
// No part of this software may be disclosed or
// distributed in any form or by any means without the prior written
// consent of MACTek Corporation
//
//==============================================================================

/*****************************************************************************
 * Build Specific Settings
 *****************************************************************************
 */

// The version number for the DD
#define DD_VERSION                      2.25


MANUFACTURER MACTEK, DEVICE_TYPE _VIATOR_VWA, DEVICE_REVISION 2, DD_REVISION 2
#define DEVICE_NAME "Bullet"

/*****************************************************************************
 * Include Files
 *****************************************************************************
 */


#include "macros.h"
#include "methods.h"
#include "DD_alerts.dd"
#include "DD_burst.dd"
#include "DD_power.dd"
#include "DD_subdevices.dd"
#include "DD_variables.dd"
#include "DD_wireless.dd"


/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */

#define UPDATE_IN_PROGRESS      8
#define DEVICE_BUSY             32
#define MAXIMUM_RESET_RETRIES   10
#define INCLUDE_EVENTS          1


/*****************************************************************************
 * Definitions (#define, typedef, enum)
 *****************************************************************************
 */


/*****************************************************************************
 * Common Tables
 */

IMPORT STANDARD _TABLES, DEVICE_REVISION 20, DD_REVISION 4
{
    // Import all so that we get all device types for subdevices attached to the adapter.
    EVERYTHING;

    REDEFINITIONS
    {
        /* 
         * This must be redefined if the Device Type is not listed
         * in Common Tables DD
         */
        VARIABLE device_type
        {
            REDEFINE TYPE ENUMERATED (2)
            {
                // replace the 0xf9f3 with your expanded device type code and appropriete label
                { 0xE0AC,  "Wireless Adapter" }
            }
        }

        /*
         * This must be redefined if the Manufacturer code is not listed
         * in the Common Tables DD
         */
        VARIABLE manufacturer_id
        {
            REDEFINE TYPE ENUMERATED (2)
            {
                // replace the 0x00f9 with your manufactures id and appropriate label
                { 0x6019,  [MACTek] } 
            }
        }

        /*
         * This must be redefined if the Manufacturer code is not listed
         * in the Common Tables DD
         */
        VARIABLE private_label_distributor
        {
            REDEFINE TYPE ENUMERATED (2)
            {
                { 0x6019,  [MACTek] } 
            }
        }

        VARIABLE burst_mode_select
        {
            REDEFINE TYPE ENUMERATED
            {
                BURST_MODE_CONTROL_CODE(0),  /* Off */                
                { 2,  "Enabled",  "Enabled on WirelessHART device connection only" }             
            }
        }

        VARIABLE event_notification_control_n
        {
           REDEFINE TYPE ENUMERATED
            {
                BURST_MODE_CONTROL_CODE(0),  /* Off */                
                { 2,  "Enabled",  "Enabled on WirelessHART device connection only" }             
            }
        }

       /* 
	    * Remove the following if the device supports trends.  Corresponding
        * commands will also need to be imported from the COMMON_PRACTICE DD.
	    */
        DELETE VARIABLE trend_digital_units;
        DELETE VARIABLE trend_classification;
        DELETE VARIABLE trend_control_codes;
        DELETE VARIABLE trend_control;

        //Commands 821,822 are optional for wireless devices - remove if device does not support
        DELETE VARIABLE network_access_mode;

         //Command 89 is not typically supported by wireless adapters
        DELETE VARIABLE time_set;     
    }
}

/*****************************************************************************
 * Universal Commmands
 */

IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 7, DD_REVISION 2
{
    // All HART devices must support all Universal Commands
    EVERYTHING;

    REDEFINITIONS
    {        
        COMMAND read_dynamic_variables_and_pv_current
        {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status,
                    PV.DAQ.ANALOG_VALUE,
                    PV.DEVICE_VARIABLE.DIGITAL_UNITS, PV.DEVICE_VARIABLE.DIGITAL_VALUE                    
                }
            }
        }
        
        
 
        /* Redefine the command 48 status to match
           the device implementation.  The same should
           also be done for device_specific_status_0_mask
           and device_specific_status_0_latched_value
           example for 1 byte follows: */
        VARIABLE device_specific_status_0
        {
            REDEFINE LABEL "Device Specific Status 0";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "Stack Overflow", MISC },
                { 0x02, "Burst Messages Dropped", MISC },
                { 0x04, "Incorrect Power Mode", MISC },
                { 0x08, "Bad Loop Switch Parameters", MISC },
                { 0x10, "Bad Burst Configuration", MISC },
                { 0x20, "Subdevice Dropped", MISC },
                { 0x40, "Duplicate Poll Addr Detected", MISC },
                { 0x80, "Wired Burst Mode Detected", MISC }
            }
        }
        VARIABLE device_specific_status_1
        {
            REDEFINE LABEL "Device Specific Status 1";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "Wireless Join Failed", MISC }
                { 0x02, "Loop Switch Cutoff Voltage Tripped", MISC }
            }
        }

        //Remove the command 48 status bytes that are not supported by the adapter
        //See also command 48 related items in the common practice imports.
        COMMAND read_additional_device_status
        {
            REDEFINE TRANSACTION 0
            {
                REQUEST
                {}
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0, device_specific_status_1, device_specific_status_2,
                    device_specific_status_3, device_specific_status_4, device_specific_status_5,
        
                    extended_fld_device_status, 0x00, 
                    
                    standardized_status_0, standardized_status_1, analog_channel_saturated1,
                    standardized_status_2, standardized_status_3
                }
            }

            REDEFINE TRANSACTION 1
            {
                REQUEST
                {
                    device_specific_status_0 (INFO), device_specific_status_1 (INFO), device_specific_status_2 (INFO),
                    device_specific_status_3 (INFO), device_specific_status_4 (INFO), device_specific_status_5 (INFO),
        
                    extended_fld_device_status (INFO), 0x00, 
                    
                    standardized_status_0 (INFO), standardized_status_1 (INFO), analog_channel_saturated1 (INFO),
                    standardized_status_2 (INFO), standardized_status_3 (INFO)
                }
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0 (INFO), device_specific_status_1 (INFO), device_specific_status_2 (INFO),
                    device_specific_status_3 (INFO), device_specific_status_4 (INFO), device_specific_status_5 (INFO),
        
                    extended_fld_device_status (INFO), 0x00, 
                    
                    standardized_status_0 (INFO), standardized_status_1 (INFO), analog_channel_saturated1 (INFO),
                    standardized_status_2 (INFO), standardized_status_3 (INFO)
                }
            }
        }
    }
}


/*****************************************************************************
 * PV, when the primary variable is not mappable we can import the PV
 * standard DD to take care of the dynamic variable array, loop current
 * and ranging functions
 */

IMPORT STANDARD _PV, DEVICE_REVISION 1, DD_REVISION 1
{
    EVERYTHING;
    REDEFINITIONS
    {


        /* Redefine PV so that only non-special variables can be mapped.
           This is necessary for hosts that do not support re-entrant
           array references. */
        COLLECTION OF VARIABLE primary_variable
        {
            MEMBERS
            {
                REDEFINE DEVICE_VARIABLE, mappableVariables[0];
            }
        }

        VARIABLE transfer_function
        {            
            REDEFINE HANDLING READ & WRITE;
            REDEFINE TYPE ENUMERATED
            {
                { 0,   [linear],     [linear_help] },
                { 4,   "Special Curve",     [special_curve_help] }
            }
        }
        

        COLLECTION OF VARIABLE scaling
        {
            REDEFINE MEMBERS
            {
                /* Range Information */
                RANGE_UNITS,            deviceVariables[0].DIGITAL_UNITS, [range_units], [range_units_help];
                PERCENT_RANGE,          percentRange,       [percent_of_range],     [percent_of_range_help];
                TRANSFER_FUNCTION,      transfer_function,  "Linearization Mode",   [transfer_function_help];
                UPPER_RANGE_VALUE,      upperRange_value,   "Upper Range Value (20 mA)",  [upper_range_value_help];
                LOWER_RANGE_VALUE,      lowerRange_value,   "Lower Range Value (4 mA)",  [lower_range_value_help];
            }
        }
    }
}


ARRAY OF COLLECTION mappableVariables
{
    ELEMENTS
    {
          0, devVar0,     "Device Variable 0";
    }
}


/*****************************************************************************
 * Common Practice Commands
 */

IMPORT STANDARD _COMMON_PRACTICE, DEVICE_REVISION 9, DD_REVISION 2
{

    //For a wireless adapter, these are the minimal commands required (in the device) for compliance
    //commented items are required in the device, but not modeled in a DD
    COMMAND write_pv_damping_value;                     // Command 34
    COMMAND write_pv_range_values;                      // Command 35
    COMMAND enter_exit_fixed_pv_current_mode;           // Command 40
    COMMAND perform_self_test;                          // Command 41 
    COMMAND perform_device_reset;                       // Command 42 
    COMMAND write_pv_units;                             // Command 44
    COMMAND trim_pv_current_dac_zero;                   // Command 45
    COMMAND trim_pv_current_dac_gain;                   // Command 46
    COMMAND write_pv_transfer_function;                 // Command 47
    COMMAND write_device_variable_units;                // Command 53
    COMMAND read_device_variable_information;           // Command 54                                                            
    COMMAND write_number_of_response_preambles;         // Command 59
    COMMAND read_io_system_capabilities;                // Command 74

    //COMMAND read_io_channel_stats;                      // Command 85

    COMMAND write_io_system_master_mode;                // Command 87
    COMMAND write_io_system_retry_count;                // Command 88
    COMMAND read_device_communication_statistics;       // Command 95
    COMMAND read_subdevice_burst_map;                   // Command 101
    COMMAND write_subdevice_burst_map;                  // Command 102
    COMMAND write_burst_period;                         // Command 103
    COMMAND write_burst_trigger;                        // Command 104
    COMMAND read_burst_mode_configuration;              // Command 105
    COMMAND flush_delayed_responses;                    // Command 106
    COMMAND write_burst_device_variables;               // Command 107
    COMMAND write_burst_command_number;                 // Command 108
    COMMAND burst_mode_control;                         // Command 109                                                   
    COMMAND read_event_notification_summary;            // Command 115
    COMMAND write_event_notification_bit_mask;          // Command 116
    COMMAND write_event_notification_timing;            // Command 117
    COMMAND event_notification_control;                 // Command 118
    COMMAND acknowledge_event_notification;             // Command 119

    COMMAND read_country_code;                          // Command 512
    COMMAND write_country_code;                         // Command 513

    VARIABLE max_io_cards;                              // for Command 74
    VARIABLE max_channels_per_io_card;                  // for Command 74
    VARIABLE max_sub_dev_per_channel;                   // for Command 74
    VARIABLE devices_detected;                          // for Command 74
    VARIABLE max_dr;                                    // for Command 74
    VARIABLE retry_count;                               // for Command 74, 88
    VARIABLE device_variable_code;                      // for Command 79    
    VARIABLE device_variable_trim_code;                 // for Commands 80-83
                                                        // 

    VARIABLE subdevice_number;                          // for Command 84, 86
    LIST     subdevice_list;                            // for Command 84, 86
    VARIABLE IO_card_number;                            // for Command 85
    VARIABLE IO_channel_number;                         // for Command 85
    ARRAY card0_channels;                               // for ARRAY io_card_list
    ARRAY OF ARRAY io_cards;                            // for Command 85 
    VARIABLE current_date;                              // for Command 90
    VARIABLE current_time;                              // for Command 90
    VARIABLE last_clock_date;                           // for Command 90
    VARIABLE last_clock_time;                           // for Command 90
    VARIABLE burst_message_number;                      // for Command 103, 104, 105, 107, 108, 109
    VARIABLE update_period;                             // for collection burst_message_collection
    VARIABLE max_update_period;                         // for collection burst_message_collection
    VARIABLE burst_variable_code;                       // for collection burst_message_collection
    ARRAY    burst_variable_codes;                      // for collection burst_message_collection
    //VARIABLE burst_subdevice_index;                     // for Command 101, 102
    //ARRAY burst_messages;                               // for Command 103, 104, 105, 107, 108, 109

    VARIABLE eventNumber;                               // for Command 115, 116, 117, 118, 119
    VARIABLE time_of_first_unack_event;                 // for collection event_control
    VARIABLE event_notification_retry_time_event;       // for collection event_control
    VARIABLE max_update_time_event;                     // for collection event_control
    VARIABLE event_debounce_interval_event;             // for collection event_control
    VARIABLE event_subdevice_index;                     // for Command 101, 102
    //ARRAY events;  

    VARIABLE STX_count;                                 // for Command 95
    VARIABLE ACK_count;                                 // for Command 95
    VARIABLE BACK_count;                                // for Command 95
    VARIABLE total_number_burst_messages;               // for Command 105
    VARIABLE subdev_IO_card;                            // for collection subdev_identity
    VARIABLE subdev_channel;                            // for collection subdev_identity
    VARIABLE subdev_device_id;                          // for collection subdev_identity
    VARIABLE subdev_universal_command_revision;         // for collection subdev_identity
    VARIABLE subdev_long_tag;                           // for collection subdev_identity
    VARIABLE stx_sent_to_subdev;                        // for collection subdev_stats
    VARIABLE ack_received_from_subdev;                  // for collection subdev_stats
    VARIABLE back_received_from_subdev;                 // for collection subdev_stats
    VARIABLE io_channel_stx_sent;                       // for collection io_stats
    VARIABLE io_channel_ack_received;                   // for collection io_stats
    VARIABLE io_channel_ostx_received;                  // for collection io_stats
    VARIABLE io_channel_oack_received;                  // for collection io_stats
    VARIABLE io_channel_back_received;                  // for collection io_stats
    VARIABLE burst_command_number;                      // for collection burst_message_collection
    VARIABLE trigger_level;                             // for collection burst_message_collection

    VARIABLE number_events_supported;                   // for Command 115
    VARIABLE device_specific_status_0_mask;             // for collection event_mask
    VARIABLE device_specific_status_1_mask;             // for collection event_mask
    VARIABLE device_specific_status_2_mask;             // for collection event_mask
    VARIABLE device_specific_status_3_mask;             // for collection event_mask
    VARIABLE device_specific_status_4_mask;             // for collection event_mask
    VARIABLE device_specific_status_5_mask;             // for collection event_mask

    /*
     * Adapters handle events on behalf of subdevices,
     * so ALL status masks must be imported so that
     * subdevices with any number of status bytes can
     * be supported.
     */
    VARIABLE device_specific_status_14_mask;            // for collection event_mask
    VARIABLE device_specific_status_15_mask;            // for collection event_mask
    VARIABLE device_specific_status_16_mask;            // for collection event_mask
    VARIABLE device_specific_status_17_mask;            // for collection event_mask
    VARIABLE device_specific_status_18_mask;            // for collection event_mask
    VARIABLE device_specific_status_19_mask;            // for collection event_mask
    VARIABLE device_specific_status_20_mask;            // for collection event_mask
    VARIABLE device_specific_status_21_mask;            // for collection event_mask
    VARIABLE device_specific_status_22_mask;            // for collection event_mask
    VARIABLE device_specific_status_23_mask;            // for collection event_mask
    VARIABLE device_specific_status_24_mask;            // for collection event_mask
    VARIABLE device_specific_status_0_latched_value;    // for collection event_report
    VARIABLE device_specific_status_1_latched_value;    // for collection event_report
    VARIABLE device_specific_status_2_latched_value;    // for collection event_report
    VARIABLE device_specific_status_3_latched_value;    // for collection event_report
    VARIABLE device_specific_status_4_latched_value;    // for collection event_report
    VARIABLE device_specific_status_5_latched_value;    // for collection event_report

    /*
     * Adapters handle events on behalf of subdevices,
     * so ALL status masks must be imported so that
     * subdevices with any number of status bytes can
     * be supported.
     */
    VARIABLE device_specific_status_14_latched_value;   // for collection event_report
    VARIABLE device_specific_status_15_latched_value;   // for collection event_report
    VARIABLE device_specific_status_16_latched_value;   // for collection event_report
    VARIABLE device_specific_status_17_latched_value;   // for collection event_report
    VARIABLE device_specific_status_18_latched_value;   // for collection event_report
    VARIABLE device_specific_status_19_latched_value;   // for collection event_report
    VARIABLE device_specific_status_20_latched_value;   // for collection event_report
    VARIABLE device_specific_status_21_latched_value;   // for collection event_report
    VARIABLE device_specific_status_22_latched_value;   // for collection event_report
    VARIABLE device_specific_status_23_latched_value;   // for collection event_report
    VARIABLE device_specific_status_24_latched_value;   // for collection event_report
    VARIABLE config_change_counter_latched_value;       // for collection event_report
    COLLECTION event_control;                           // for ARRAY event_array
    COLLECTION event_mask;                              // for ARRAY event_array
    COLLECTION event_report;                            // for ARRAY event_array
    COLLECTION event;                                   // for ARRAY event_array

    VARIABLE constOne;                                  // for command 101,102
    VARIABLE constZero;                                 // for command 101,102
    VARIABLE subdevice_missing;                         // for command 101,102

    //UNIT burst_trigger_units_relation;

    COLLECTION subdev_identity;                         // for collection sub_device
    COLLECTION subdev_stats;                            // for collection sub_device
    COLLECTION sub_device;                              // for LIST subdevice_list
    COLLECTION io_stats;                                // for LIST channel_list
    //COLLECTION burst_message_collection;                // for ARRAY burst_message_array

    METHOD leave_fixed_current_mode;
    METHOD return_to_normal;
    METHOD warning_message;
    METHOD device_self_test;
    METHOD device_variable_trim;
    METHOD zero_trim;
    METHOD device_variable_zero_trim;
    METHOD trim_warning;
    METHOD device_variable_trim_reset;
    METHOD transmitter_dac_trim;


    REDEFINITIONS
    {
        /* Following commands and data must be redefined for hosts
           which do not support Lists and Value-Arrays. */
#if __TOKVER__ >= 800
        VARIABLE burst_message_number
        {
            REDEFINE TYPE INDEX compat_burst_messages;
        }
#endif


#if (__TOKVER__ >= 800) && (INCLUDE_EVENTS)
        VARIABLE eventNumber
        {
            REDEFINE TYPE INDEX compat_events;
        }

        COLLECTION OF VARIABLE event_control
         {
            MEMBERS {
                REDEFINE EVENT_STATUS,                               compat_event_status_1,                             "Status";
                REDEFINE EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_1,             "Event Notification Control";
                REDEFINE TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_1,                "Event Time Stamp";
                REDEFINE EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_1,      "Retry Time";
                REDEFINE MAX_UPDATE_TIME,                            compat_max_update_time_event_1,                    "Max Update Time";
                REDEFINE EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_1,            "Debounce";
                REDEFINE SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_0,                "Subdevice Tag";
                ADD TIME_OF_FIRST_UNACK_EVENT_ASCII,                 time_of_first_unack_event_ascii,                   "Time of First Unack Event Triggered";
                ADD DATE_OF_FIRST_UNACK_EVENT,                       date_of_first_unack_event,                         "Date of First Unack Event Triggered";
            }
        }
#endif

        VARIABLE constZero
        {
            REDEFINE TYPE UNSIGNED_INTEGER
            {
                MIN_VALUE 0x00;  //This is to help for hosts which do not implement DEFAULT_VALUE properly
            }
        #if __TOKVER__ >= 600
            REDEFINE DEFAULT_VALUE 0x00;
        #endif
        }

        VARIABLE burst_variable_code
        {
            REDEFINE TYPE INDEX deviceVariablesBurst;
        }

        // Define the list of commands that can be burst by the adapter (add any device specific commands too)
        VARIABLE burst_command_number
        {
            REDEFINE TYPE ENUMERATED (2)
            {
                {1,  [read_primary_variable], [pv_help] }, 
                {2,  [read_percent_range_and_current], [percent_rnge_help] }, 
                {3,  [read_dyn_vars_and_current], [all_process_var_help] }, 
                {9,  [read_device_variables_with_status], [read_device_variables_with_status_help] }, 
                {33, [read_device_variables],[read_device_variables_help] },
                {48, "Cmd 48: Read Additional Device Status", "Read Additional Device - This command reads additional device status information"}                
                {778, "Cmd 778: Read Battery Life", "Read Battery Life - This command reads the battery life of the device"}                 
            }
        }

        #if 0
        /* The event masks and reported values should be
           redefined similar to the command 48 byte
           redefinitions in the UNIVERSAL imports. */
        VARIABLE device_specific_status_0_mask
        {
            REDEFINE LABEL "Status example 1 Mask";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "Example condition 1", MISC },
                { 0x02, "Example condition 2", MISC },
                { 0x04, "Example condition 3", MISC },
                { 0x08, "Example condition 4", MISC },
                { 0x10, "Example condition 5", MISC },
                { 0x20, "Example condition 6", MISC },
                { 0x40, "Example condition 7", MISC },
                { 0x80, "Example condition 8", MISC }
            }
        }

        VARIABLE device_specific_status_0_latched_value
        {
            REDEFINE LABEL "Latched Status example 1";
            REDEFINE TYPE BIT_ENUMERATED
            {
                { 0x01, "Example condition 1", MISC },
                { 0x02, "Example condition 2", MISC },
                { 0x04, "Example condition 3", MISC },
                { 0x08, "Example condition 4", MISC },
                { 0x10, "Example condition 5", MISC },
                { 0x20, "Example condition 6", MISC },
                { 0x40, "Example condition 7", MISC },
                { 0x80, "Example condition 8", MISC }
            }
        }

        #endif

 /*
         * Commands 101, 102 
         * Version 5 tokenizer can not handle adjacent masks
         * (ie, <0x8000> and <0x7FFF> so can not use member SUB_DEVICE_MISSING;
         * will use SUB_DEVICE_MAPPING.
         * Older legacy hosts that read .fm8 & can not handle Value Array "burst_messages"
         * so will use ARRAY OF COLLECTION "compat_burst_messages"
         */
        REDEFINE COMMAND read_subdevice_burst_map
        {
            NUMBER 101;
            OPERATION READ;
#if __TOKVER__ >= 800
            TRANSACTION 0  //For Burst messages
            {
                REQUEST
                {
                    constZero <0x80> (INFO), // MSB = 0 for burst messages
                    burst_message_number <0x7F> (INFO, INDEX)
                }
                REPLY
                {
                    response_code, device_status,
                    constZero <0x80> (INFO),
                    burst_message_number <0x7F> (INFO, INDEX),
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MISSING <0x8000>,
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MAPPING <0x7FFF>
                }
            }
#if INCLUDE_EVENTS
            /* If events are not included, then the command 101 transaction
               dealing with the event notifications needs to be removed.
	       If they are included for tokenizer version 8, multiple events
	       are redefined to use reference array. */
            TRANSACTION 1  //For events
            {
                REQUEST
                {
                    constOne <0x80> (INFO),   // MSB = 1 for events
                    eventNumber <0x7F> (INFO, INDEX)
                }
                REPLY
                {
                    response_code, device_status,
                    constOne <0x80> (INFO),
                    eventNumber <0x7F> (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.SUB_DEVICE_MISSING <0x8000>,
                    compat_events[eventNumber].EVENT_CONTROL.SUB_DEVICE_MAPPING <0x7FFF>
                }
            }
#endif

#else
            TRANSACTION 0  //For Burst messages
            {
                REQUEST
                {
                    constZero <0x80> (INFO), // MSB = 0 for burst messages
                    constZero <0x7F> (INFO)
                }
                REPLY
                {
                    response_code, device_status,
                    constZero <0x80> (INFO),
                    burst_message_number <0x7F> (INFO),
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MAPPING
                }
            }
#if INCLUDE_EVENTS
            /* If events are not included, then the command 101 transaction
               dealing with the event notifications needs to be removed.
	       If they are included for tokenizer version 5, we need to remove
	       references to COLLECTION of COLLECTION. Keep tokenizer version 6
	       consistent with version 5. */
            TRANSACTION 1  //For events
            {
                REQUEST
                {
                    constOne <0x80> (INFO),   // MSB = 1 for events
                    constZero <0x7F> (INFO)
                }
                REPLY
                {
                    response_code, device_status,
                    constOne <0x80> (INFO),
                    constZero <0x7F> (INFO),
                    event_control.SUB_DEVICE_MAPPING
                }
            }
#endif
#endif

            RESPONSE_CODES
            {
                0,  SUCCESS,          [no_command_specific_errors];
                2,  DATA_ENTRY_ERROR, [invalid_selection];
                5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
                6,  MISC_ERROR,       [xmtr_specific_command_error];
            }
        }

        REDEFINE COMMAND write_subdevice_burst_map
        {
            NUMBER 102;
            OPERATION WRITE;
#if __TOKVER__ >= 800
            TRANSACTION 0  //For Burst messages
            {
                REQUEST
                {
                    constZero <0x80> (INFO), // MSB = 0 for burst messages
                    burst_message_number <0x7F> (INFO, INDEX),
                    constZero <0x8000>,
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MAPPING <0x7FFF>
                }
                REPLY
                {
                    response_code, device_status,
                    constZero <0x80> (INFO),
                    burst_message_number <0x7F> (INFO, INDEX),
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MISSING <0x8000>,
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MAPPING <0x7FFF>
                }
            }
#if INCLUDE_EVENTS
            /* If events are not included, then the command 102 transaction
               dealing with the event notifications needs to be removed.
	       If they are included for tokenizer version 8, multiple events
	       are redefined to use reference array. */
            TRANSACTION 1  //For events
            {
                REQUEST
                {
                    constOne <0x80> (INFO),   // MSB = 1 for events
                    eventNumber <0x7F> (INFO, INDEX),
                    constZero <0x8000>,
                    compat_events[eventNumber].EVENT_CONTROL.SUB_DEVICE_MAPPING <0x7FFF>
                }
                REPLY
                {
                    response_code, device_status,
                    constOne <0x80> (INFO),
                    eventNumber <0x7F> (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.SUB_DEVICE_MISSING <0x8000>,
                    compat_events[eventNumber].EVENT_CONTROL.SUB_DEVICE_MAPPING <0x7FFF>
                }
            }
#endif
#else
            TRANSACTION 0  //For Burst messages
            {
                REQUEST
                {
                    constZero <0x80> (INFO), // MSB = 0 for burst messages
                    burst_message_number <0x7F> (INFO, INDEX),
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MAPPING
                }
                REPLY
                {
                    response_code, device_status,
                    constZero <0x80> (INFO),
                    constZero <0x7F> (INFO),
                    compat_burst_messages[burst_message_number].SUB_DEVICE_MAPPING
                }
            }

#if INCLUDE_EVENTS
            /* If events are not included, then the command 102 transaction
               dealing with the event notifications needs to be removed.
	       If they are included for tokenizer version 5, we need to remove
	       references to COLLECTION of COLLECTION. Keep tokenizer version 6
	       consistent with version 5. */
            TRANSACTION 1  //For events
            {
                REQUEST
                {
                    constOne <0x80> (INFO),   // MSB = 1 for events
                    constZero <0x7F> (INFO),
                    event_control.SUB_DEVICE_MAPPING
                }
                REPLY
                {
                    response_code, device_status,
                    constOne <0x80> (INFO),
                    constZero <0x7F> (INFO),
                    event_control.SUB_DEVICE_MAPPING
                }
            }
#endif
#endif
            RESPONSE_CODES
            {
                0,  SUCCESS,          [no_command_specific_errors];
                2,  DATA_ENTRY_ERROR, [invalid_selection];
                5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
                6,  MISC_ERROR,       [xmtr_specific_command_error];
                7,  MODE_ERROR,       [in_write_protect_mode];
                9,  DATA_ENTRY_ERROR, "Invalid subdevice index";
                16, MODE_ERROR,       [access_restricted];
            }
        }

        /*
         * Commands 103, 104, 105, 108, 109
         * Older legacy hosts that read .fm8 & can not handle Value Array "burst_messages"
         * will use ARRAY OF COLLECTION "compat_burst_messages"
         */

        // Command 103
        COMMAND write_burst_period
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                    burst_message_number (INFO, INDEX),
                    compat_burst_messages[burst_message_number].UPDATE_PERIOD,
                    compat_burst_messages[burst_message_number].MAX_UPDATE_PERIOD
                }
                REPLY
                {
                    response_code, device_status,
                    burst_message_number (INFO, INDEX),
                    compat_burst_messages[burst_message_number].UPDATE_PERIOD,
                    compat_burst_messages[burst_message_number].MAX_UPDATE_PERIOD
                }
            }
        }

        // Command 104
        COMMAND write_burst_trigger
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                    burst_message_number (INFO, INDEX),
                    compat_burst_messages[burst_message_number].BURST_TRIGGER_MODE,
                    compat_burst_messages[burst_message_number].BURST_CLASSIFICATION,
                    compat_burst_messages[burst_message_number].BURST_UNIT,
                    compat_burst_messages[burst_message_number].TRIGGER_LEVEL
                }
                REPLY
                {
                    response_code, device_status,
                    burst_message_number (INFO, INDEX),
                    compat_burst_messages[burst_message_number].BURST_TRIGGER_MODE,
                    compat_burst_messages[burst_message_number].BURST_CLASSIFICATION,
                    compat_burst_messages[burst_message_number].BURST_UNIT,
                    compat_burst_messages[burst_message_number].TRIGGER_LEVEL
                }
            }
        }

        /*
         * Command 105
         * Older legacy hosts that read .fm8 & can not handle Value Array "burst_messages"
         * will use ARRAY OF ARRAY compat_burst_vars, which uses ARRAY OF VARIABLE
         * "compat_burst_vars_0", "compat_burst_vars_1", "compat_burst_vars_2",
         * "compat_burst_vars_3"
         */
        COMMAND read_burst_mode_configuration
        {
            REDEFINE TRANSACTION
            {
                REQUEST 
                {
                    burst_message_number (INFO, INDEX)
                }
                REPLY
                {
                    response_code, device_status,
                    compat_burst_messages[burst_message_number].BURST_MODE_SELECT,
                    0x1F,
                    compat_burst_vars[burst_message_number][0],        
                    compat_burst_vars[burst_message_number][1],        
                    compat_burst_vars[burst_message_number][2],        
                    compat_burst_vars[burst_message_number][3],        
                    compat_burst_vars[burst_message_number][4],        
                    compat_burst_vars[burst_message_number][5],        
                    compat_burst_vars[burst_message_number][6],        
                    compat_burst_vars[burst_message_number][7], 
                    burst_message_number (INFO, INDEX),
                    total_number_burst_messages,
                    compat_burst_messages[burst_message_number].COMMAND_NUMBER,
                    compat_burst_messages[burst_message_number].UPDATE_PERIOD,
                    compat_burst_messages[burst_message_number].MAX_UPDATE_PERIOD,
                    compat_burst_messages[burst_message_number].BURST_TRIGGER_MODE,
                    compat_burst_messages[burst_message_number].BURST_CLASSIFICATION,
                    compat_burst_messages[burst_message_number].BURST_UNIT,
                    compat_burst_messages[burst_message_number].TRIGGER_LEVEL
                }
            }
        }

        /*
         * Command 107
         * Older legacy hosts that read .fm8 & can not handle Value Array "burst_messages"
         * will use ARRAY OF ARRAY compat_burst_vars, which uses ARRAY OF VARIABLE
         * "compat_burst_vars_0", "compat_burst_vars_1", "compat_burst_vars_2",
         * "compat_burst_vars_3"
         */
        COMMAND write_burst_device_variables
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                       compat_burst_vars[burst_message_number][0],        
                       compat_burst_vars[burst_message_number][1],        
                       compat_burst_vars[burst_message_number][2],        
                       compat_burst_vars[burst_message_number][3],        
                       compat_burst_vars[burst_message_number][4],        
                       compat_burst_vars[burst_message_number][5],        
                       compat_burst_vars[burst_message_number][6],        
                       compat_burst_vars[burst_message_number][7], 
                       burst_message_number (INFO, INDEX)
                }
        
                REPLY
                {
                       response_code, device_status,
                       compat_burst_vars[burst_message_number][0],        
                       compat_burst_vars[burst_message_number][1],        
                       compat_burst_vars[burst_message_number][2],        
                       compat_burst_vars[burst_message_number][3],        
                       compat_burst_vars[burst_message_number][4],        
                       compat_burst_vars[burst_message_number][5],        
                       compat_burst_vars[burst_message_number][6],        
                       compat_burst_vars[burst_message_number][7], 
                       burst_message_number (INFO, INDEX)
                }
            }
        }

        // Command 108
        COMMAND write_burst_command_number
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                    compat_burst_messages[burst_message_number].COMMAND_NUMBER,
                    burst_message_number (INFO, INDEX)
                }
        
                REPLY
                {
                    response_code, device_status,
                    compat_burst_messages[burst_message_number].COMMAND_NUMBER,
                    burst_message_number (INFO, INDEX)
                }
            }
        }

#if (INCLUDE_EVENTS)

        /*
         * Commands 115, 116, 117, 118, 119
         * Version 5 tokenizer has trouble importing some COLLECTION of COLLECTIONS.
	 * Redefine command to drop one level of indirection. Keep version 6 consistent
	 * with version 5.
         */

        // Command 115
        COMMAND read_event_notification_summary
        {
            REDEFINE TRANSACTION
            {
#if __TOKVER__ >= 800
                REQUEST
                {
                    eventNumber (INFO, INDEX)
                }
                REPLY
                {
                    response_code, device_status,
                    eventNumber (INFO, INDEX),
                    number_events_supported,
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_STATUS<0xf0>,
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_NOTIFICATION_CONTROL<0x0f>,
                    compat_events[eventNumber].EVENT_CONTROL.TIME_OF_FIRST_UNACK_EVENT,
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_NOTIFICATION_RETRY_TIME,
                    compat_events[eventNumber].EVENT_CONTROL.MAX_UPDATE_TIME,
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_DEBOUNCE_INTERVAL,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_STATUS_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_0_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_1_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_2_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_3_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_4_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_5_MASK,
                    compat_events[eventNumber].EVENT_MASK.EXTENDED_FLD_DEVICE_STATUS_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEV_OPERATING_MODE_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_0_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_1_MASK,
                    compat_events[eventNumber].EVENT_MASK.ANALOG_CHANNEL_SATURATED1_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_2_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_3_MASK,
                    compat_events[eventNumber].EVENT_MASK.ANALOG_CHANNEL_FIXED1_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_14_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_15_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_16_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_17_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_18_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_19_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_20_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_21_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_22_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_23_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_24_MASK
                }
#else // Tokenizer versions 5 & 6 only support 1 event, and tokenizer version 5 has trouble using collection of collection

                REQUEST
                {
                    0
                }
                REPLY
                {
                    response_code, device_status,
                    0,
                    number_events_supported,
                    event_control.EVENT_STATUS<0xf0>,
                    event_control.EVENT_NOTIFICATION_CONTROL<0x0f>,
                    event_control.TIME_OF_FIRST_UNACK_EVENT,
                    event_control.EVENT_NOTIFICATION_RETRY_TIME,
                    event_control.MAX_UPDATE_TIME,
                    event_control.EVENT_DEBOUNCE_INTERVAL,
                    event_mask.DEVICE_STATUS_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_0_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_1_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_2_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_3_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_4_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_5_MASK,
                    event_mask.EXTENDED_FLD_DEVICE_STATUS_MASK,
                    event_mask.DEV_OPERATING_MODE_MASK,
                    event_mask.STANDARDIZED_STATUS_0_MASK,
                    event_mask.STANDARDIZED_STATUS_1_MASK,
                    event_mask.ANALOG_CHANNEL_SATURATED1_MASK,
                    event_mask.STANDARDIZED_STATUS_2_MASK,
                    event_mask.STANDARDIZED_STATUS_3_MASK,
                    event_mask.ANALOG_CHANNEL_FIXED1_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_14_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_15_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_16_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_17_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_18_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_19_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_20_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_21_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_22_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_23_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_24_MASK
                }
#endif
            }
        }
#endif

#if (INCLUDE_EVENTS)
        // Command 116
        COMMAND write_event_notification_bit_mask
        {
            REDEFINE TRANSACTION
            {
#if __TOKVER__ >= 800
                REQUEST
                {
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_MASK.DEVICE_STATUS_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_0_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_1_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_2_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_3_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_4_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_5_MASK,
                    compat_events[eventNumber].EVENT_MASK.EXTENDED_FLD_DEVICE_STATUS_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEV_OPERATING_MODE_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_0_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_1_MASK,
                    compat_events[eventNumber].EVENT_MASK.ANALOG_CHANNEL_SATURATED1_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_2_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_3_MASK,
                    compat_events[eventNumber].EVENT_MASK.ANALOG_CHANNEL_FIXED1_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_14_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_15_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_16_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_17_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_18_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_19_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_20_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_21_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_22_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_23_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_24_MASK
                }
                REPLY
                {
                    response_code, device_status,
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_MASK.DEVICE_STATUS_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_0_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_1_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_2_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_3_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_4_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_5_MASK,
                    compat_events[eventNumber].EVENT_MASK.EXTENDED_FLD_DEVICE_STATUS_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEV_OPERATING_MODE_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_0_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_1_MASK,
                    compat_events[eventNumber].EVENT_MASK.ANALOG_CHANNEL_SATURATED1_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_2_MASK,
                    compat_events[eventNumber].EVENT_MASK.STANDARDIZED_STATUS_3_MASK,
                    compat_events[eventNumber].EVENT_MASK.ANALOG_CHANNEL_FIXED1_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_14_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_15_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_16_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_17_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_18_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_19_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_20_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_21_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_22_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_23_MASK,
                    compat_events[eventNumber].EVENT_MASK.DEVICE_SPECIFIC_STATUS_24_MASK
                }
#else // Tokenizer versions 5 & 6 only support 1 event, and tokenizer version 5 has trouble using collection of collection
                REQUEST
                {
                    0,
                    event_mask.DEVICE_STATUS_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_0_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_1_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_2_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_3_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_4_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_5_MASK,
                    event_mask.EXTENDED_FLD_DEVICE_STATUS_MASK,
                    event_mask.DEV_OPERATING_MODE_MASK,
                    event_mask.STANDARDIZED_STATUS_0_MASK,
                    event_mask.STANDARDIZED_STATUS_1_MASK,
                    event_mask.ANALOG_CHANNEL_SATURATED1_MASK,
                    event_mask.STANDARDIZED_STATUS_2_MASK,
                    event_mask.STANDARDIZED_STATUS_3_MASK,
                    event_mask.ANALOG_CHANNEL_FIXED1_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_14_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_15_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_16_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_17_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_18_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_19_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_20_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_21_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_22_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_23_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_24_MASK
              
                }
                REPLY
                {
                    response_code, device_status,
                    0,
                    event_mask.DEVICE_STATUS_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_0_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_1_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_2_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_3_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_4_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_5_MASK,
                    event_mask.EXTENDED_FLD_DEVICE_STATUS_MASK,
                    event_mask.DEV_OPERATING_MODE_MASK,
                    event_mask.STANDARDIZED_STATUS_0_MASK,
                    event_mask.STANDARDIZED_STATUS_1_MASK,
                    event_mask.ANALOG_CHANNEL_SATURATED1_MASK,
                    event_mask.STANDARDIZED_STATUS_2_MASK,
                    event_mask.STANDARDIZED_STATUS_3_MASK,
                    event_mask.ANALOG_CHANNEL_FIXED1_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_14_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_15_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_16_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_17_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_18_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_19_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_20_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_21_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_22_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_23_MASK,
                    event_mask.DEVICE_SPECIFIC_STATUS_24_MASK
                }
#endif
            }
        }
#endif
// Need to have some non ifdef'd code here to avoid having a scanner input overflow error.
        COMMAND burst_mode_control
        {
            REDEFINE TRANSACTION
            {
                REQUEST
                {
                    compat_burst_messages[burst_message_number].BURST_MODE_SELECT,
                    burst_message_number (INFO, INDEX)
                }
                REPLY
                {
                    response_code, device_status,
                    compat_burst_messages[burst_message_number].BURST_MODE_SELECT,
                    burst_message_number (INFO, INDEX)
                }
            }
        }

#if INCLUDE_EVENTS
        // Command 117
        COMMAND write_event_notification_timing
        {
            REDEFINE TRANSACTION
            {
#if __TOKVER__ >= 800
                REQUEST
                {
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_NOTIFICATION_RETRY_TIME,
                    compat_events[eventNumber].EVENT_CONTROL.MAX_UPDATE_TIME,
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_DEBOUNCE_INTERVAL
                }
                REPLY
                {
                    response_code, device_status,
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_NOTIFICATION_RETRY_TIME,
                    compat_events[eventNumber].EVENT_CONTROL.MAX_UPDATE_TIME,
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_DEBOUNCE_INTERVAL
                }
#else // Tokenizer version 5 can not reliably import a collection of collection, so drop down 1 level of indirection
                REQUEST
                {
                    0,
                    event_control.EVENT_NOTIFICATION_RETRY_TIME,
                    event_control.MAX_UPDATE_TIME,
                    event_control.EVENT_DEBOUNCE_INTERVAL
                }
                REPLY
                {
                    response_code, device_status,
                    0,
                    event_control.EVENT_NOTIFICATION_RETRY_TIME,
                    event_control.MAX_UPDATE_TIME,
                    event_control.EVENT_DEBOUNCE_INTERVAL
                }
#endif
            }
        }
#endif

#if INCLUDE_EVENTS
        // Command 118
        COMMAND event_notification_control
        {
            REDEFINE TRANSACTION
            {
#if __TOKVER__ >= 800
                REQUEST
                {
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_NOTIFICATION_CONTROL
                }
                REPLY
                {
                    response_code, device_status,
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.EVENT_NOTIFICATION_CONTROL
                }
#else // Tokenizer version 5 can not reliably import a collection of collection, so drop down 1 level of indirection
                REQUEST
                {
                    0,
                    event_control.EVENT_NOTIFICATION_CONTROL
                }
                REPLY
                {
                    response_code, device_status,
                    0,
                    event_control.EVENT_NOTIFICATION_CONTROL
                }
#endif
            }
        }
#endif

#if INCLUDE_EVENTS
        // Command 119
        COMMAND acknowledge_event_notification
        {
            REDEFINE TRANSACTION 0  // Used to get the latest outstanding event
            {
#if __TOKVER__ >= 800
                REQUEST
                {
                    eventNumber (INFO, INDEX)
                }
                REPLY
                {
                    response_code, device_status,
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.TIME_OF_FIRST_UNACK_EVENT,
                    compat_events[eventNumber].EVENT_REPORT.CONFIG_CHANGE_COUNTER_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_STATUS_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEV_OPERATING_MODE_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_0_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_1_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_2_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_3_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE
                }
#else  // Tokenizer version 5 can not reliably import a collection of collection, so drop down 1 level of indirection
                REQUEST
                {
                    0
                }
                REPLY
                {
                    response_code, device_status,
                    0,
                    event_control.TIME_OF_FIRST_UNACK_EVENT,
                    event_report.CONFIG_CHANGE_COUNTER_LATCHED_VALUE,
                    event_report.DEVICE_STATUS_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,
                    event_report.EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,
                    event_report.DEV_OPERATING_MODE_LATCHED_VALUE,
                    event_report.STANDARDIZED_STATUS_0_LATCHED_VALUE,
                    event_report.STANDARDIZED_STATUS_1_LATCHED_VALUE,
                    event_report.ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,
                    event_report.STANDARDIZED_STATUS_2_LATCHED_VALUE,
                    event_report.STANDARDIZED_STATUS_3_LATCHED_VALUE,
                    event_report.ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,
                    event_report.DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE
                }
#endif
            }

            REDEFINE TRANSACTION 1 // Used to ACK an outstanding event
            {
#if __TOKVER__ >= 800
                REQUEST
                {
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.TIME_OF_FIRST_UNACK_EVENT (INFO),
                    compat_events[eventNumber].EVENT_REPORT.CONFIG_CHANGE_COUNTER_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_STATUS_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEV_OPERATING_MODE_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_0_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_2_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_3_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.ANALOG_CHANNEL_FIXED1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE (INFO)
                }
                REPLY
                {
                    response_code, device_status,
                    eventNumber (INFO, INDEX),
                    compat_events[eventNumber].EVENT_CONTROL.TIME_OF_FIRST_UNACK_EVENT (INFO),
                    compat_events[eventNumber].EVENT_REPORT.CONFIG_CHANGE_COUNTER_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_STATUS_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEV_OPERATING_MODE_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_0_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_2_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.STANDARDIZED_STATUS_3_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.ANALOG_CHANNEL_FIXED1_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE (INFO),
                    compat_events[eventNumber].EVENT_REPORT.DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE (INFO)
                }
#else  // Tokenizer version 5 can not reliably import a collection of collection, so drop down 1 level of indirection
                REQUEST
                {
                    0,
                    event_control.TIME_OF_FIRST_UNACK_EVENT (INFO),
                    event_report.CONFIG_CHANGE_COUNTER_LATCHED_VALUE (INFO),
                    event_report.DEVICE_STATUS_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE (INFO),
                    event_report.EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE (INFO),
                    event_report.DEV_OPERATING_MODE_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_0_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_1_LATCHED_VALUE (INFO),
                    event_report.ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_2_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_3_LATCHED_VALUE (INFO),
                    event_report.ANALOG_CHANNEL_FIXED1_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE (INFO)
                }
                REPLY
                {
                    response_code, device_status,
                    0,
                    event_control.TIME_OF_FIRST_UNACK_EVENT (INFO),
                    event_report.CONFIG_CHANGE_COUNTER_LATCHED_VALUE (INFO),
                    event_report.DEVICE_STATUS_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE (INFO),
                    event_report.EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE (INFO),
                    event_report.DEV_OPERATING_MODE_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_0_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_1_LATCHED_VALUE (INFO),
                    event_report.ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_2_LATCHED_VALUE (INFO),
                    event_report.STANDARDIZED_STATUS_3_LATCHED_VALUE (INFO),
                    event_report.ANALOG_CHANNEL_FIXED1_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE (INFO),
                    event_report.DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE (INFO)
                }
#endif
            }
        }
#endif

    }
}


IMPORT STANDARD _WIRELESS, DEVICE_REVISION 1, DD_REVISION 2
{
    EVERYTHING;

    REDEFINITIONS
    {
        // Commands 821,822 are optional for adapters - remove if device does not support
        DELETE COMMAND write_network_access_mode;
        DELETE COMMAND read_network_access_mode;
        DELETE COMMAND read_network_tag;
        DELETE COMMAND write_radio_power_output;
        DELETE COMMAND read_radio_output_power;
        DELETE VARIABLE radio_power_output;
    }
}


/* Because IO Adapters do not know what device variables are
   supported in the subdevice that it will be attached to,
   all entries from 0-249 need to be declared so that all
   possible burst variable codes will be valid. For the
   variable indexes not used for this device, the other
   indexes will point to a global data holder to save size. */
/* Variables 243-249 are predefined variables that should be
   supported if applicable to the device. */
/* This Array of device variables includes the common defined HCF variables.
   They cannot be made a part of the deviceVariables array because it causes
   a recursive definition which causes older versions of the tokenizer to
   crash when generating the ptoc table. */ 
ARRAY OF COLLECTION deviceVariablesBurst
{
    ELEMENTS
    {
        0, scratchData,           "Device Variable 0";    // Shouldn't use names specific to this device because these could be for subdevices
        1, scratchData,           "Device Variable 1";
        2, scratchData,           "Device Variable 2";
        3, scratchData,           "Device Variable 3";
        4, scratchData,           "Device Variable 4";
        5, scratchData,           "Device Variable 5";
        6, scratchData,           "Device Variable 6";
        7, scratchData,           "Device Variable 7";
        8, scratchData,           "Device Variable 8";
        9, scratchData,           "Device Variable 9";
        10, scratchData,          "Device Variable 10";
        11, scratchData,          "Device Variable 11";
        12, scratchData,          "Device Variable 12";
        13, scratchData,          "Device Variable 13";
        14, scratchData,          "Device Variable 14";
        15, scratchData,          "Device Variable 15";
        16, scratchData,          "Device Variable 16";
        17, scratchData,          "Device Variable 17";
        18, scratchData,          "Device Variable 18";
        19, scratchData,          "Device Variable 19";
        20, scratchData,          "Device Variable 20";
        21, scratchData,          "Device Variable 21";
        22, scratchData,          "Device Variable 22";
        23, scratchData,          "Device Variable 23";
        24, scratchData,          "Device Variable 24";
        25, scratchData,          "Device Variable 25";
        26, scratchData,          "Device Variable 26";
        27, scratchData,          "Device Variable 27";
        28, scratchData,          "Device Variable 28";
        29, scratchData,          "Device Variable 29";
        30, scratchData,          "Device Variable 30";
        31, scratchData,          "Device Variable 31";
        32, scratchData,          "Device Variable 32";
        33, scratchData,          "Device Variable 33";
        34, scratchData,          "Device Variable 34";
        35, scratchData,          "Device Variable 35";
        36, scratchData,          "Device Variable 36";
        37, scratchData,          "Device Variable 37";
        38, scratchData,          "Device Variable 38";
        39, scratchData,          "Device Variable 39";
        40, scratchData,          "Device Variable 40";
        41, scratchData,          "Device Variable 41";
        42, scratchData,          "Device Variable 42";
        43, scratchData,          "Device Variable 43";
        44, scratchData,          "Device Variable 44";
        45, scratchData,          "Device Variable 45";
        46, scratchData,          "Device Variable 46";
        47, scratchData,          "Device Variable 47";
        48, scratchData,          "Device Variable 48";
        49, scratchData,          "Device Variable 49";
        50, scratchData,          "Device Variable 50";
        51, scratchData,          "Device Variable 51";
        52, scratchData,          "Device Variable 52";
        53, scratchData,          "Device Variable 53";
        54, scratchData,          "Device Variable 54";
        55, scratchData,          "Device Variable 55";
        56, scratchData,          "Device Variable 56";
        57, scratchData,          "Device Variable 57";
        58, scratchData,          "Device Variable 58";
        59, scratchData,          "Device Variable 59";
        60, scratchData,          "Device Variable 60";
        61, scratchData,          "Device Variable 61";
        62,  scratchData,         "Device Variable 62";
        63,  scratchData,         "Device Variable 63";
        64,  scratchData,         "Device Variable 64";
        65,  scratchData,         "Device Variable 65";
        66,  scratchData,         "Device Variable 66";
        67,  scratchData,         "Device Variable 67";
        68,  scratchData,         "Device Variable 68";
        69,  scratchData,         "Device Variable 69";
        70,  scratchData,         "Device Variable 70";
        71,  scratchData,         "Device Variable 71";
        72,  scratchData,         "Device Variable 72";
        73,  scratchData,         "Device Variable 73";
        74,  scratchData,         "Device Variable 74";
        75,  scratchData,         "Device Variable 75";
        76,  scratchData,         "Device Variable 76";
        77,  scratchData,         "Device Variable 77";
        78,  scratchData,         "Device Variable 78";
        79,  scratchData,         "Device Variable 79";
        80,  scratchData,         "Device Variable 80";
        81,  scratchData,         "Device Variable 81";
        82,  scratchData,         "Device Variable 82";
        83,  scratchData,         "Device Variable 83";
        84,  scratchData,         "Device Variable 84";
        85,  scratchData,         "Device Variable 85";
        86,  scratchData,         "Device Variable 86";
        87,  scratchData,         "Device Variable 87";
        88,  scratchData,         "Device Variable 88";
        89,  scratchData,         "Device Variable 89";
        90,  scratchData,         "Device Variable 90";
        91,  scratchData,         "Device Variable 91";
        92,  scratchData,         "Device Variable 92";
        93,  scratchData,         "Device Variable 93";
        94,  scratchData,         "Device Variable 94";
        95,  scratchData,         "Device Variable 95";
        96,  scratchData,         "Device Variable 96";
        97,  scratchData,         "Device Variable 97";
        98,  scratchData,         "Device Variable 98";
        99,  scratchData,         "Device Variable 99";
        100, scratchData,         "Device Variable 100";
        101, scratchData,         "Device Variable 101";
        102, scratchData,         "Device Variable 102";
        103, scratchData,         "Device Variable 103";
        104, scratchData,         "Device Variable 104";
        105, scratchData,         "Device Variable 105";
        106, scratchData,         "Device Variable 106";
        107, scratchData,         "Device Variable 107";
        108, scratchData,         "Device Variable 108";
        109, scratchData,         "Device Variable 109";
        110, scratchData,         "Device Variable 110";
        111, scratchData,         "Device Variable 111";
        112, scratchData,         "Device Variable 112";
        113, scratchData,         "Device Variable 113";
        114, scratchData,         "Device Variable 114";
        115, scratchData,         "Device Variable 115";
        116, scratchData,         "Device Variable 116";
        117, scratchData,         "Device Variable 117";
        118, scratchData,         "Device Variable 118";
        119, scratchData,         "Device Variable 119";
        120, scratchData,         "Device Variable 120";
        121, scratchData,         "Device Variable 121";
        122, scratchData,         "Device Variable 122";
        123, scratchData,         "Device Variable 123";
        124, scratchData,         "Device Variable 124";
        125, scratchData,         "Device Variable 125";
        126, scratchData,         "Device Variable 126";
        127, scratchData,         "Device Variable 127";
        128, scratchData,         "Device Variable 128";
        129, scratchData,         "Device Variable 129";
        130, scratchData,         "Device Variable 130";
        131, scratchData,         "Device Variable 131";
        132, scratchData,         "Device Variable 132";
        133, scratchData,         "Device Variable 133";
        134, scratchData,         "Device Variable 134";
        135, scratchData,         "Device Variable 135";
        136, scratchData,         "Device Variable 136";
        137, scratchData,         "Device Variable 137";
        138, scratchData,         "Device Variable 138";
        139, scratchData,         "Device Variable 139";
        140, scratchData,         "Device Variable 140";
        141, scratchData,         "Device Variable 141";
        142, scratchData,         "Device Variable 142";
        143, scratchData,         "Device Variable 143";
        144, scratchData,         "Device Variable 144";
        145, scratchData,         "Device Variable 145";
        146, scratchData,         "Device Variable 146";
        147, scratchData,         "Device Variable 147";
        148, scratchData,         "Device Variable 148";
        149, scratchData,         "Device Variable 149";
        150, scratchData,         "Device Variable 150";
        151, scratchData,         "Device Variable 151";
        152, scratchData,         "Device Variable 152";
        153, scratchData,         "Device Variable 153";
        154, scratchData,         "Device Variable 154";
        155, scratchData,         "Device Variable 155";
        156, scratchData,         "Device Variable 156";
        157, scratchData,         "Device Variable 157";
        158, scratchData,         "Device Variable 158";
        159, scratchData,         "Device Variable 159";
        160, scratchData,         "Device Variable 160";
        161, scratchData,         "Device Variable 161";
        162, scratchData,         "Device Variable 162";
        163, scratchData,         "Device Variable 163";
        164, scratchData,         "Device Variable 164";
        165, scratchData,         "Device Variable 165";
        166, scratchData,         "Device Variable 166";
        167, scratchData,         "Device Variable 167";
        168, scratchData,         "Device Variable 168";
        169, scratchData,         "Device Variable 169";
        170, scratchData,         "Device Variable 170";
        171, scratchData,         "Device Variable 171";
        172, scratchData,         "Device Variable 172";
        173, scratchData,         "Device Variable 173";
        174, scratchData,         "Device Variable 174";
        175, scratchData,         "Device Variable 175";
        176, scratchData,         "Device Variable 176";
        177, scratchData,         "Device Variable 177";
        178, scratchData,         "Device Variable 178";
        179, scratchData,         "Device Variable 179";
        180, scratchData,         "Device Variable 180";
        181, scratchData,         "Device Variable 181";
        182, scratchData,         "Device Variable 182";
        183, scratchData,         "Device Variable 183";
        184, scratchData,         "Device Variable 184";
        185, scratchData,         "Device Variable 185";
        186, scratchData,         "Device Variable 186";
        187, scratchData,         "Device Variable 187";
        188, scratchData,         "Device Variable 188";
        189, scratchData,         "Device Variable 189";
        190, scratchData,         "Device Variable 190";
        191, scratchData,         "Device Variable 191";
        192, scratchData,         "Device Variable 192";
        193, scratchData,         "Device Variable 193";
        194, scratchData,         "Device Variable 194";
        195, scratchData,         "Device Variable 195";
        196, scratchData,         "Device Variable 196";
        197, scratchData,         "Device Variable 197";
        198, scratchData,         "Device Variable 198";
        199, scratchData,         "Device Variable 199";
        200, scratchData,         "Device Variable 200";
        201, scratchData,         "Device Variable 201";
        202, scratchData,         "Device Variable 202";
        203, scratchData,         "Device Variable 203";
        204, scratchData,         "Device Variable 204";
        205, scratchData,         "Device Variable 205";
        206, scratchData,         "Device Variable 206";
#if __TOKVER__ >= 800
        207, scratchData,         "Device Variable 207";
        208, scratchData,         "Device Variable 208";
        209, scratchData,         "Device Variable 209";
        210, scratchData,         "Device Variable 210";
        211, scratchData,         "Device Variable 211";
        212, scratchData,         "Device Variable 212";
        213, scratchData,         "Device Variable 213";
        214, scratchData,         "Device Variable 214";
        215, scratchData,         "Device Variable 215";
        216, scratchData,         "Device Variable 216";
        217, scratchData,         "Device Variable 217";
        218, scratchData,         "Device Variable 218";
        219, scratchData,         "Device Variable 219";
        220, scratchData,         "Device Variable 220";
        221, scratchData,         "Device Variable 221";
        222, scratchData,         "Device Variable 222";
        223, scratchData,         "Device Variable 223";
        224, scratchData,         "Device Variable 224";
        225, scratchData,         "Device Variable 225";
        226, scratchData,         "Device Variable 226";
        227, scratchData,         "Device Variable 227";
        228, scratchData,         "Device Variable 228";
        229, scratchData,         "Device Variable 229";
        230, scratchData,         "Device Variable 230";
        231, scratchData,         "Device Variable 231";
        232, scratchData,         "Device Variable 232";
        233, scratchData,         "Device Variable 233";
        234, scratchData,         "Device Variable 234";
        235, scratchData,         "Device Variable 235";
        236, scratchData,         "Device Variable 236";
        237, scratchData,         "Device Variable 237";
        238, scratchData,         "Device Variable 238";
        239, scratchData,         "Device Variable 239";
        240, scratchData,         "Device Variable 240";
        241, scratchData,         "Device Variable 241";
        242, scratchData,         "Device Variable 242";
#endif
        243, scratchData,         device_variable_code_codes(243);
        244, scratchData,         device_variable_code_codes(244);
        245, scratchData,         device_variable_code_codes(245);
        246, scratchData,         device_variable_code_codes(246);
        247, scratchData,         device_variable_code_codes(247);
        248, scratchData,         device_variable_code_codes(248);
        249, scratchData,         device_variable_code_codes(249);
        250, scratchData,         [not_used];

        /* 
         * Uncomment each variable if used in this device, and remove from above list
         */
        //247, SV.DEVICE_VARIABLE,  device_variable_code_codes(247);
        //248, TV.DEVICE_VARIABLE,  device_variable_code_codes(248);
        //249, QV.DEVICE_VARIABLE,  device_variable_code_codes(249);
    }
}


#if __TOKVER__ >= 800 //If we do not have the power of value array, we need to define unique copies of each burst paramater
compat_burst_vars_1_0 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_0 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_0 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_0 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_0 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_0 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_0 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
#endif

/* Some versions of some host systems overwrite the burst_mode_select value based on the
   burst mode bit in the Data Link Layer.  This is holdover from previous HART universal
   revisions as an optimization due to the fact that there was no read command to find out
   from the device if burst mode was enabled or not.  This does not work for wireless
   devices because the DLL burst mode bit on wired interface does not reflect the state of
   burst mode on the wireless interface. Define a new burst_mode_select bit to avoid
   this optimization from negatively affecting the DD. */
compat_burst_mode_0 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }

ARRAY OF VARIABLE compat_burst_vars_0
{
    ELEMENTS
    {
        0, burst_variable_code, "Burst Variable Code 0";
        1, compat_burst_vars_1_0, "Burst Variable Code 1";
        2, compat_burst_vars_2_0, "Burst Variable Code 2";
        3, compat_burst_vars_3_0, "Burst Variable Code 3";
        4, compat_burst_vars_4_0, "Burst Variable Code 4";
        5, compat_burst_vars_5_0, "Burst Variable Code 5";
        6, compat_burst_vars_6_0, "Burst Variable Code 6";
        7, compat_burst_vars_7_0, "Burst Variable Code 7";
    }
}

#if __TOKVER__ < 800
VARIABLE burst_message_number
{
    LABEL "Burst Message Number";
    HELP "";
    CLASS LOCAL;
    TYPE INDEX compat_burst_messages;
}
#endif


compat_burst_cmd_1 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_1 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_1 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_1 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_1 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_1 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_1 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_1 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_1 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_1 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_1 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_1 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_1 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_1 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_1 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_1 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_1 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_1 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }

ARRAY OF VARIABLE compat_burst_vars_1
{
    ELEMENTS
    {
        0, compat_burst_vars_0_1, "Burst Variable Code 0";
        1, compat_burst_vars_1_1, "Burst Variable Code 1";
        2, compat_burst_vars_2_1, "Burst Variable Code 2";
        3, compat_burst_vars_3_1, "Burst Variable Code 3";
        4, compat_burst_vars_4_1, "Burst Variable Code 4";
        5, compat_burst_vars_5_1, "Burst Variable Code 5";
        6, compat_burst_vars_6_1, "Burst Variable Code 6";
        7, compat_burst_vars_7_1, "Burst Variable Code 7";
    }
}

compat_burst_cmd_2 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_2 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_2 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_2 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_2 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_2 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_2 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_2 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_2 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_2 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_2 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_2 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_2 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_2 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_2 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_2 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_2 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_2 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_2
{
    ELEMENTS
    {
        0, compat_burst_vars_0_2, "Burst Variable Code 0";
        1, compat_burst_vars_1_2, "Burst Variable Code 1";
        2, compat_burst_vars_2_2, "Burst Variable Code 2";
        3, compat_burst_vars_3_2, "Burst Variable Code 3";
        4, compat_burst_vars_4_2, "Burst Variable Code 4";
        5, compat_burst_vars_5_2, "Burst Variable Code 5";
        6, compat_burst_vars_6_2, "Burst Variable Code 6";
        7, compat_burst_vars_7_2, "Burst Variable Code 7";
    }
}

compat_burst_cmd_3 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_3 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_3 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_3 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_3 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_3 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_3 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_3 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_3 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_3 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_3 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_3 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_3 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_3 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_3 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_3 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_3 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_3 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_3
{
    ELEMENTS
    {
        0, compat_burst_vars_0_3, "Burst Variable Code 0";
        1, compat_burst_vars_1_3, "Burst Variable Code 1";
        2, compat_burst_vars_2_3, "Burst Variable Code 2";
        3, compat_burst_vars_3_3, "Burst Variable Code 3";
        4, compat_burst_vars_4_3, "Burst Variable Code 4";
        5, compat_burst_vars_5_3, "Burst Variable Code 5";
        6, compat_burst_vars_6_3, "Burst Variable Code 6";
        7, compat_burst_vars_7_3, "Burst Variable Code 7";
    }
}


compat_burst_cmd_4 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_4 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_4 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_4 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_4 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_4 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_4 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_4 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_4 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_4 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_4 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_4 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_4 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_4 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_4 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_4 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_4 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_4 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_4
{
    ELEMENTS
    {
        0, compat_burst_vars_0_4, "Burst Variable Code 0";
        1, compat_burst_vars_1_4, "Burst Variable Code 1";
        2, compat_burst_vars_2_4, "Burst Variable Code 2";
        3, compat_burst_vars_3_4, "Burst Variable Code 3";
        4, compat_burst_vars_4_4, "Burst Variable Code 4";
        5, compat_burst_vars_5_4, "Burst Variable Code 5";
        6, compat_burst_vars_6_4, "Burst Variable Code 6";
        7, compat_burst_vars_7_4, "Burst Variable Code 7";
    }
}


compat_burst_cmd_5 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_5 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_5 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_5 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_5 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_5 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_5 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_5 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_5 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_5 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_5 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_5 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_5 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_5 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_5 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_5 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_5 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_5 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_5
{
    ELEMENTS
    {
        0, compat_burst_vars_0_5, "Burst Variable Code 0";
        1, compat_burst_vars_1_5, "Burst Variable Code 1";
        2, compat_burst_vars_2_5, "Burst Variable Code 2";
        3, compat_burst_vars_3_5, "Burst Variable Code 3";
        4, compat_burst_vars_4_5, "Burst Variable Code 4";
        5, compat_burst_vars_5_5, "Burst Variable Code 5";
        6, compat_burst_vars_6_5, "Burst Variable Code 6";
        7, compat_burst_vars_7_5, "Burst Variable Code 7";
    }
}


compat_burst_cmd_6 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_6 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_6 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_6 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_6 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_6 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_6 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_6 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_6 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_6 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_6 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_6 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_6 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_6 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_6 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_6 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_6 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_6 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_6
{
    ELEMENTS
    {
        0, compat_burst_vars_0_6, "Burst Variable Code 0";
        1, compat_burst_vars_1_6, "Burst Variable Code 1";
        2, compat_burst_vars_2_6, "Burst Variable Code 2";
        3, compat_burst_vars_3_6, "Burst Variable Code 3";
        4, compat_burst_vars_4_6, "Burst Variable Code 4";
        5, compat_burst_vars_5_6, "Burst Variable Code 5";
        6, compat_burst_vars_6_6, "Burst Variable Code 6";
        7, compat_burst_vars_7_6, "Burst Variable Code 7";
    }
}


compat_burst_cmd_7 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_7 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_7 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_7 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_7 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_7 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_7 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_7 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_7 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_7 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_7 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_7 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_7 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_7 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_7 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_7 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_7 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_7 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_7
{
    ELEMENTS
    {
        0, compat_burst_vars_0_7, "Burst Variable Code 0";
        1, compat_burst_vars_1_7, "Burst Variable Code 1";
        2, compat_burst_vars_2_7, "Burst Variable Code 2";
        3, compat_burst_vars_3_7, "Burst Variable Code 3";
        4, compat_burst_vars_4_7, "Burst Variable Code 4";
        5, compat_burst_vars_5_7, "Burst Variable Code 5";
        6, compat_burst_vars_6_7, "Burst Variable Code 6";
        7, compat_burst_vars_7_7, "Burst Variable Code 7";
    }
}


compat_burst_cmd_8 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_8 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_8 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_8 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_8 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_8 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_8 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_8 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_8 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_8 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_8 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_8 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_8 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_8 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_8 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_8 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_8 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_8 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_8
{
    ELEMENTS
    {
        0, compat_burst_vars_0_8, "Burst Variable Code 0";
        1, compat_burst_vars_1_8, "Burst Variable Code 1";
        2, compat_burst_vars_2_8, "Burst Variable Code 2";
        3, compat_burst_vars_3_8, "Burst Variable Code 3";
        4, compat_burst_vars_4_8, "Burst Variable Code 4";
        5, compat_burst_vars_5_8, "Burst Variable Code 5";
        6, compat_burst_vars_6_8, "Burst Variable Code 6";
        7, compat_burst_vars_7_8, "Burst Variable Code 7";
    }
}


compat_burst_cmd_9 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_9 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_9 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_9 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_9 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_9 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_9 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_9 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_9 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_9 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_9 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_9 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_9 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_9 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_9 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_9 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_9 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_9 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_9
{
    ELEMENTS
    {
        0, compat_burst_vars_0_9, "Burst Variable Code 0";
        1, compat_burst_vars_1_9, "Burst Variable Code 1";
        2, compat_burst_vars_2_9, "Burst Variable Code 2";
        3, compat_burst_vars_3_9, "Burst Variable Code 3";
        4, compat_burst_vars_4_9, "Burst Variable Code 4";
        5, compat_burst_vars_5_9, "Burst Variable Code 5";
        6, compat_burst_vars_6_9, "Burst Variable Code 6";
        7, compat_burst_vars_7_9, "Burst Variable Code 7";
    }
}


compat_burst_cmd_10 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_10 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_10 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_10 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_10 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_10 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_10 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_10 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_10 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_10 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_10 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_10 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_10 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_10 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_10 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_10 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_10 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_10 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_10
{
    ELEMENTS
    {
        0, compat_burst_vars_0_10, "Burst Variable Code 0";
        1, compat_burst_vars_1_10, "Burst Variable Code 1";
        2, compat_burst_vars_2_10, "Burst Variable Code 2";
        3, compat_burst_vars_3_10, "Burst Variable Code 3";
        4, compat_burst_vars_4_10, "Burst Variable Code 4";
        5, compat_burst_vars_5_10, "Burst Variable Code 5";
        6, compat_burst_vars_6_10, "Burst Variable Code 6";
        7, compat_burst_vars_7_10, "Burst Variable Code 7";
    }
}


compat_burst_cmd_11 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_11 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_11 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_11 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_11 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_11 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_11 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_11 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_11 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_11 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_11 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_11 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_11 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_11 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_11 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_11 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_11 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_11 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_11
{
    ELEMENTS
    {
        0, compat_burst_vars_0_11, "Burst Variable Code 0";
        1, compat_burst_vars_1_11, "Burst Variable Code 1";
        2, compat_burst_vars_2_11, "Burst Variable Code 2";
        3, compat_burst_vars_3_11, "Burst Variable Code 3";
        4, compat_burst_vars_4_11, "Burst Variable Code 4";
        5, compat_burst_vars_5_11, "Burst Variable Code 5";
        6, compat_burst_vars_6_11, "Burst Variable Code 6";
        7, compat_burst_vars_7_11, "Burst Variable Code 7";
    }
}

compat_burst_cmd_12 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_12 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_12 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_12 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_12 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_12 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_12 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_12 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_12 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_12 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_12 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_12 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_12 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_12 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_12 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_12 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_12 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_12 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_12
{
    ELEMENTS
    {
        0, compat_burst_vars_0_12, "Burst Variable Code 0";
        1, compat_burst_vars_1_12, "Burst Variable Code 1";
        2, compat_burst_vars_2_12, "Burst Variable Code 2";
        3, compat_burst_vars_3_12, "Burst Variable Code 3";
        4, compat_burst_vars_4_12, "Burst Variable Code 4";
        5, compat_burst_vars_5_12, "Burst Variable Code 5";
        6, compat_burst_vars_6_12, "Burst Variable Code 6";
        7, compat_burst_vars_7_12, "Burst Variable Code 7";
    }
}

compat_burst_cmd_13 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_13 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_13 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_13 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_13 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_13 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_13 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_13 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_13 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_13 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_13 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_13 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_13 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_13 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_13 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_13 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_13 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_13 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_13
{
    ELEMENTS
    {
        0, compat_burst_vars_0_13, "Burst Variable Code 0";
        1, compat_burst_vars_1_13, "Burst Variable Code 1";
        2, compat_burst_vars_2_13, "Burst Variable Code 2";
        3, compat_burst_vars_3_13, "Burst Variable Code 3";
        4, compat_burst_vars_4_13, "Burst Variable Code 4";
        5, compat_burst_vars_5_13, "Burst Variable Code 5";
        6, compat_burst_vars_6_13, "Burst Variable Code 6";
        7, compat_burst_vars_7_13, "Burst Variable Code 7";
    }
}


compat_burst_cmd_14 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_14 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_14 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_14 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_14 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_14 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_14 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_14 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_14 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_14 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_14 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_14 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_14 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_14 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_14 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_14 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_14 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_14 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_14
{
    ELEMENTS
    {
        0, compat_burst_vars_0_14, "Burst Variable Code 0";
        1, compat_burst_vars_1_14, "Burst Variable Code 1";
        2, compat_burst_vars_2_14, "Burst Variable Code 2";
        3, compat_burst_vars_3_14, "Burst Variable Code 3";
        4, compat_burst_vars_4_14, "Burst Variable Code 4";
        5, compat_burst_vars_5_14, "Burst Variable Code 5";
        6, compat_burst_vars_6_14, "Burst Variable Code 6";
        7, compat_burst_vars_7_14, "Burst Variable Code 7";
    }
}


compat_burst_cmd_15 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_15 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_15 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_15 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_15 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_15 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_15 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_15 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_15 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_15 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_15 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_15 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_15 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_15 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_15 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_15 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_15 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_15 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_15
{
    ELEMENTS
    {
        0, compat_burst_vars_0_15, "Burst Variable Code 0";
        1, compat_burst_vars_1_15, "Burst Variable Code 1";
        2, compat_burst_vars_2_15, "Burst Variable Code 2";
        3, compat_burst_vars_3_15, "Burst Variable Code 3";
        4, compat_burst_vars_4_15, "Burst Variable Code 4";
        5, compat_burst_vars_5_15, "Burst Variable Code 5";
        6, compat_burst_vars_6_15, "Burst Variable Code 6";
        7, compat_burst_vars_7_15, "Burst Variable Code 7";
    }
}


compat_burst_cmd_16 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_16 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_16 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_16 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_16 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_16 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_16 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_16 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_16 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_16 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_16 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_16 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_16 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_16 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_16 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_16 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_16 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_16 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_16
{
    ELEMENTS
    {
        0, compat_burst_vars_0_16, "Burst Variable Code 0";
        1, compat_burst_vars_1_16, "Burst Variable Code 1";
        2, compat_burst_vars_2_16, "Burst Variable Code 2";
        3, compat_burst_vars_3_16, "Burst Variable Code 3";
        4, compat_burst_vars_4_16, "Burst Variable Code 4";
        5, compat_burst_vars_5_16, "Burst Variable Code 5";
        6, compat_burst_vars_6_16, "Burst Variable Code 6";
        7, compat_burst_vars_7_16, "Burst Variable Code 7";
    }
}


compat_burst_cmd_17 LIKE VARIABLE burst_command_number { REDEFINE CLASS DEVICE; }
compat_burst_mode_17 LIKE VARIABLE burst_mode_select { REDEFINE CLASS DEVICE; }
compat_update_per_17 LIKE VARIABLE update_period { REDEFINE CLASS DEVICE; }
compat_max_update_per_17 LIKE VARIABLE max_update_period { REDEFINE CLASS DEVICE; }
compat_burst_vars_0_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_1_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_2_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_3_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_4_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_5_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_6_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_vars_7_17 LIKE VARIABLE burst_variable_code { REDEFINE CLASS DEVICE; }
compat_burst_trig_mode_17 LIKE VARIABLE burst_message_trigger_mode { REDEFINE CLASS DEVICE; }
compat_burst_trig_class_17 LIKE VARIABLE burst_trigger_classification { REDEFINE CLASS DEVICE; }
compat_burst_trig_units_17 LIKE VARIABLE burst_trigger_units { REDEFINE CLASS DEVICE; }
compat_burst_trig_level_17 LIKE VARIABLE trigger_level { REDEFINE CLASS DEVICE; }
compat_subdevice_missing_17 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_burst_subdev_index_17 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
burst_message_status_17 LIKE VARIABLE burst_message_status { REDEFINE CLASS DEVICE; }
burst_date_17 LIKE VARIABLE burst_date { REDEFINE CLASS DEVICE; }
burst_time_17 LIKE VARIABLE burst_time { REDEFINE CLASS DEVICE; }
burst_data_17 LIKE VARIABLE burst_data { REDEFINE CLASS DEVICE; }
burst_data_units_17 LIKE VARIABLE burst_data_units { REDEFINE CLASS DEVICE; }
burst_data_quality_17 LIKE VARIABLE burst_data_quality { REDEFINE CLASS DEVICE; }
burst_count_17 LIKE VARIABLE burst_count { REDEFINE CLASS DEVICE; }


ARRAY OF VARIABLE compat_burst_vars_17
{
    ELEMENTS
    {
        0, compat_burst_vars_0_17, "Burst Variable Code 0";
        1, compat_burst_vars_1_17, "Burst Variable Code 1";
        2, compat_burst_vars_2_17, "Burst Variable Code 2";
        3, compat_burst_vars_3_17, "Burst Variable Code 3";
        4, compat_burst_vars_4_17, "Burst Variable Code 4";
        5, compat_burst_vars_5_17, "Burst Variable Code 5";
        6, compat_burst_vars_6_17, "Burst Variable Code 6";
        7, compat_burst_vars_7_17, "Burst Variable Code 7";
    }
}

COLLECTION OF VARIABLE compat_burst_msg_0
{
    MEMBERS
    {
        COMMAND_NUMBER,         burst_command_number,          "Burst Command";
        UPDATE_PERIOD,          update_period,                 "Update Period";
        MAX_UPDATE_PERIOD,      max_update_period,             "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_0,           "Mode";
        BURST_TRIGGER_MODE,     burst_message_trigger_mode,    "Trigger Mode";
        BURST_CLASSIFICATION,   burst_trigger_classification,  "Classification";
        BURST_UNIT,             burst_trigger_units,           "Trigger Units";
        TRIGGER_LEVEL,          trigger_level,                 "Trigger Level";
        SUB_DEVICE_MISSING,     subdevice_missing,             "Sub device missing";
        SUB_DEVICE_MAPPING,     burst_subdevice_index1,        "Subdevice Tag";
        
        BURST_STATUS,           burst_message_status,          "Status";   
        BURST_DATE,             burst_date,                    "Date";
        BURST_TIME,             burst_time ,                   "Time";
        DIGITAL_VALUE,          burst_data,                    "Value";
        DIGITAL_UNITS,          burst_data_units,              "Units";
        DATA_QUALITY,           burst_data_quality,            "Quality";
        BURST_COUNT,            burst_count,                   "Burst Msg Count";        
    }
}


COLLECTION OF VARIABLE compat_burst_msg_1
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_1,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_1,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_1,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_1,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_1,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_1,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_1,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_1,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_1,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_1,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_1,        "Status";   
        BURST_DATE,             burst_date_1,                  "Date";
        BURST_TIME,             burst_time_1,                  "Time";
        DIGITAL_VALUE,          burst_data_1,                  "Value";
        DIGITAL_UNITS,          burst_data_units_1,            "Units";
        DATA_QUALITY,           burst_data_quality_1,          "Quality";
        BURST_COUNT,            burst_count_1,                 "Burst Msg Count";   
    }
}


COLLECTION OF VARIABLE compat_burst_msg_2
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_2,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_2,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_2,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_2,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_2,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_2,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_2,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_2,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_2,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_2,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_2,        "Status";   
        BURST_DATE,             burst_date_2,                  "Date";
        BURST_TIME,             burst_time_2,                  "Time";
        DIGITAL_VALUE,          burst_data_2,                  "Value";
        DIGITAL_UNITS,          burst_data_units_2,            "Units";
        DATA_QUALITY,           burst_data_quality_2,          "Quality";
        BURST_COUNT,            burst_count_2,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_3
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_3,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_3,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_3,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_3,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_3,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_3,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_3,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_3,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_3,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_3,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_3,        "Status";   
        BURST_DATE,             burst_date_3,                  "Date";
        BURST_TIME,             burst_time_3,                  "Time";
        DIGITAL_VALUE,          burst_data_3,                  "Value";
        DIGITAL_UNITS,          burst_data_units_3,            "Units";
        DATA_QUALITY,           burst_data_quality_3,          "Quality";
        BURST_COUNT,            burst_count_3,                 "Burst Msg Count";    
    }
}

COLLECTION OF VARIABLE compat_burst_msg_4
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_4,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_4,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_4,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_4,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_4,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_4,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_4,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_4,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_4,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_4,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_4,        "Status";   
        BURST_DATE,             burst_date_4,                  "Date";
        BURST_TIME,             burst_time_4,                  "Time";
        DIGITAL_VALUE,          burst_data_4,                  "Value";
        DIGITAL_UNITS,          burst_data_units_4,            "Units";
        DATA_QUALITY,           burst_data_quality_4,          "Quality";
        BURST_COUNT,            burst_count_4,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_5
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_5,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_5,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_5,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_5,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_5,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_5,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_5,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_5,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_5,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_5,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_5,        "Status";   
        BURST_DATE,             burst_date_5,                  "Date";
        BURST_TIME,             burst_time_5,                  "Time";
        DIGITAL_VALUE,          burst_data_5,                  "Value";
        DIGITAL_UNITS,          burst_data_units_5,            "Units";
        DATA_QUALITY,           burst_data_quality_5,          "Quality";
        BURST_COUNT,            burst_count_5,                 "Burst Msg Count";    
    }
}

COLLECTION OF VARIABLE compat_burst_msg_6
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_6,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_6,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_6,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_6,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_6,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_6,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_6,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_6,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_6,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_6,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_6,        "Status";   
        BURST_DATE,             burst_date_6,                  "Date";
        BURST_TIME,             burst_time_6,                  "Time";
        DIGITAL_VALUE,          burst_data_6,                  "Value";
        DIGITAL_UNITS,          burst_data_units_6,            "Units";
        DATA_QUALITY,           burst_data_quality_6,          "Quality";
        BURST_COUNT,            burst_count_6,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_7
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_7,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_7,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_7,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_7,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_7,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_7,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_7,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_7,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_7,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_7,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_7,        "Status";   
        BURST_DATE,             burst_date_7,                  "Date";
        BURST_TIME,             burst_time_7,                  "Time";
        DIGITAL_VALUE,          burst_data_7,                  "Value";
        DIGITAL_UNITS,          burst_data_units_7,            "Units";
        DATA_QUALITY,           burst_data_quality_7,          "Quality";
        BURST_COUNT,            burst_count_7,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_8
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_8,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_8,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_8,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_8,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_8,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_8,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_8,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_8,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_8,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_8,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_8,        "Status";   
        BURST_DATE,             burst_date_8,                  "Date";
        BURST_TIME,             burst_time_8,                  "Time";
        DIGITAL_VALUE,          burst_data_8,                  "Value";
        DIGITAL_UNITS,          burst_data_units_8,            "Units";
        DATA_QUALITY,           burst_data_quality_8,          "Quality";
        BURST_COUNT,            burst_count_8,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_9
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_9,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_9,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_9,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_9,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_9,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_9,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_9,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_9,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_9,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_9,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_9,        "Status";   
        BURST_DATE,             burst_date_9,                  "Date";
        BURST_TIME,             burst_time_9,                  "Time";
        DIGITAL_VALUE,          burst_data_9,                  "Value";
        DIGITAL_UNITS,          burst_data_units_9,            "Units";
        DATA_QUALITY,           burst_data_quality_9,          "Quality";
        BURST_COUNT,            burst_count_9,                 "Burst Msg Count";    
    }
}

COLLECTION OF VARIABLE compat_burst_msg_10
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_10,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_10,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_10,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_10,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_10,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_10,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_10,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_10,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_10,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_10,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_10,        "Status";   
        BURST_DATE,             burst_date_10,                  "Date";
        BURST_TIME,             burst_time_10,                  "Time";
        DIGITAL_VALUE,          burst_data_10,                  "Value";
        DIGITAL_UNITS,          burst_data_units_10,            "Units";
        DATA_QUALITY,           burst_data_quality_10,          "Quality";
        BURST_COUNT,            burst_count_10,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_11
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_11,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_11,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_11,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_11,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_11,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_11,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_11,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_11,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_11,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_11,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_11,        "Status";   
        BURST_DATE,             burst_date_11,                  "Date";
        BURST_TIME,             burst_time_11,                  "Time";
        DIGITAL_VALUE,          burst_data_11,                  "Value";
        DIGITAL_UNITS,          burst_data_units_11,            "Units";
        DATA_QUALITY,           burst_data_quality_11,          "Quality";
        BURST_COUNT,            burst_count_11,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_12
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_12,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_12,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_12,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_12,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_12,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_12,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_12,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_12,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_12,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_12,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_12,        "Status";   
        BURST_DATE,             burst_date_12,                  "Date";
        BURST_TIME,             burst_time_12,                  "Time";
        DIGITAL_VALUE,          burst_data_12,                  "Value";
        DIGITAL_UNITS,          burst_data_units_12,            "Units";
        DATA_QUALITY,           burst_data_quality_12,          "Quality";
        BURST_COUNT,            burst_count_12,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_13
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_13,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_13,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_13,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_13,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_13,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_13,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_13,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_13,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_13,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_13,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_13,        "Status";   
        BURST_DATE,             burst_date_13,                  "Date";
        BURST_TIME,             burst_time_13,                  "Time";
        DIGITAL_VALUE,          burst_data_13,                  "Value";
        DIGITAL_UNITS,          burst_data_units_13,            "Units";
        DATA_QUALITY,           burst_data_quality_13,          "Quality";
        BURST_COUNT,            burst_count_13,                 "Burst Msg Count";    
    }
}

COLLECTION OF VARIABLE compat_burst_msg_14
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_14,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_14,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_14,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_14,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_14,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_14,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_14,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_14,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_14,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_14,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_14,        "Status";   
        BURST_DATE,             burst_date_14,                  "Date";
        BURST_TIME,             burst_time_14,                  "Time";
        DIGITAL_VALUE,          burst_data_14,                  "Value";
        DIGITAL_UNITS,          burst_data_units_14,            "Units";
        DATA_QUALITY,           burst_data_quality_14,          "Quality";
        BURST_COUNT,            burst_count_14,                 "Burst Msg Count";    
    }
}

COLLECTION OF VARIABLE compat_burst_msg_15
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_15,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_15,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_15,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_15,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_15,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_15,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_15,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_15,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_15,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_15,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_15,        "Status";   
        BURST_DATE,             burst_date_15,                  "Date";
        BURST_TIME,             burst_time_15,                  "Time";
        DIGITAL_VALUE,          burst_data_15,                  "Value";
        DIGITAL_UNITS,          burst_data_units_15,            "Units";
        DATA_QUALITY,           burst_data_quality_15,          "Quality";
        BURST_COUNT,            burst_count_15,                 "Burst Msg Count";    
    }
}


COLLECTION OF VARIABLE compat_burst_msg_16
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_16,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_16,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_16,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_16,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_16,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_16,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_16,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_16,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_16,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_16,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_16,        "Status";   
        BURST_DATE,             burst_date_16,                  "Date";
        BURST_TIME,             burst_time_16,                  "Time";
        DIGITAL_VALUE,          burst_data_16,                  "Value";
        DIGITAL_UNITS,          burst_data_units_16,            "Units";
        DATA_QUALITY,           burst_data_quality_16,          "Quality";
        BURST_COUNT,            burst_count_16,                 "Burst Msg Count";    
    }
}

COLLECTION OF VARIABLE compat_burst_msg_17
{
    MEMBERS {
        COMMAND_NUMBER,         compat_burst_cmd_17,            "Burst Command";
        UPDATE_PERIOD,          compat_update_per_17,           "Update Period";
        MAX_UPDATE_PERIOD,      compat_max_update_per_17,       "Max Update Period";
        BURST_MODE_SELECT,      compat_burst_mode_17,           "Mode";
        BURST_TRIGGER_MODE,     compat_burst_trig_mode_17,      "Trigger Mode";
        BURST_CLASSIFICATION,   compat_burst_trig_class_17,     "Classification";
        BURST_UNIT,             compat_burst_trig_units_17,     "Trigger Units";
        TRIGGER_LEVEL,          compat_burst_trig_level_17,     "Trigger Level";
        SUB_DEVICE_MISSING,     compat_subdevice_missing_17,    "Sub device missing";
        SUB_DEVICE_MAPPING,     compat_burst_subdev_index_17,   "Subdevice Tag";

        BURST_STATUS,           burst_message_status_17,        "Status";   
        BURST_DATE,             burst_date_17,                  "Date";
        BURST_TIME,             burst_time_17,                  "Time";
        DIGITAL_VALUE,          burst_data_17,                  "Value";
        DIGITAL_UNITS,          burst_data_units_17,            "Units";
        DATA_QUALITY,           burst_data_quality_17,          "Quality";
        BURST_COUNT,            burst_count_17,                 "Burst Msg Count";    
    }
}

ARRAY OF COLLECTION compat_burst_messages
{
    LABEL "Burst Messages";
    ELEMENTS
    {
        0, compat_burst_msg_0;
        1, compat_burst_msg_1;
        2, compat_burst_msg_2;
        3, compat_burst_msg_3;
        4, compat_burst_msg_4;
        5, compat_burst_msg_5;
        6, compat_burst_msg_6;
        7, compat_burst_msg_7;
        8, compat_burst_msg_8;
        9, compat_burst_msg_9;
        10, compat_burst_msg_10;
        11, compat_burst_msg_11;
        12, compat_burst_msg_12;
        13, compat_burst_msg_13;
        14, compat_burst_msg_14;
        15, compat_burst_msg_15;
        16, compat_burst_msg_16;
        17, compat_burst_msg_17;
    }
}

ARRAY OF ARRAY compat_burst_vars
{
    ELEMENTS
    {
        0, compat_burst_vars_0;
        1, compat_burst_vars_1;
        2, compat_burst_vars_2;
        3, compat_burst_vars_3;
        4, compat_burst_vars_4;
        5, compat_burst_vars_5;
        6, compat_burst_vars_6;
        7, compat_burst_vars_7;
        8, compat_burst_vars_8;
        9, compat_burst_vars_9;
        10, compat_burst_vars_10;
        11, compat_burst_vars_11;
        12, compat_burst_vars_12;
        13, compat_burst_vars_13;
        14, compat_burst_vars_14;
        15, compat_burst_vars_15;
        16, compat_burst_vars_16;
        17, compat_burst_vars_17;        
    }
}


/* Tokenizer versions 5 and 6 only support a single event, and tokenizer version 5
   has trouble importing a collection of collections, so don't use the following
   constructs for anything other than tokenizer version 8.  For tokenizer
   version 8, if we do not have the power of the value array, we need to create duplicate
   copy of event veriables for each event supported.  Adapters need to support at least
   2 events. */
#if (__TOKVER__ >= 800) && (INCLUDE_EVENTS)
compat_event_subdevice_index_int_0 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }

compat_event_subdevice_index_int_1 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_1 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_1 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_1 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_1 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_1 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_1 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_1 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_1 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_1 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_1 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_1 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_1 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_1 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_1 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_1 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_1 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_1 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_1 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_1 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_1 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_1 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_1 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_1 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_1 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_1 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii1 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event1 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_1 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_1 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_1 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_1 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_1 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_1 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_1 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_1 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_1 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_1 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_1 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_1 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_1 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_1 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_1 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_1 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_1 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_1 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_1 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_1 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_1 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_1 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_1 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_1 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_1 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_1 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_1 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_1 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_1 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_1 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_1 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_1 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_1 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_1 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_1 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }


compat_event_subdevice_index_int_2 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_2 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_2 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_2 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_2 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_2 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_2 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_2 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_2 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_2 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_2 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_2 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_2 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_2 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_2 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_2 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_2 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_2 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_2 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_2 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_2 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_2 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_2 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_2 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_2 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_2 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii2 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event2 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_2 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_2 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_2 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_2 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_2 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_2 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_2 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_2 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_2 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_2 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_2 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_2 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_2 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_2 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_2 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_2 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_2 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_2 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_2 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_2 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_2 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_2 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_2 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_2 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_2 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_2 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_2 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_2 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_2 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_2 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_2 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_2 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_2 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_2 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_2 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }


compat_event_subdevice_index_int_3 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_3 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_3 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_3 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_3 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_3 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_3 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_3 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_3 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_3 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_3 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_3 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_3 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_3 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_3 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_3 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_3 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_3 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_3 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_3 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_3 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_3 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_3 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_3 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_3 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_3 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii3 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event3 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_3 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_3 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_3 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_3 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_3 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_3 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_3 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_3 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_3 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_3 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_3 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_3 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_3 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_3 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_3 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_3 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_3 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_3 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_3 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_3 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_3 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_3 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_3 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_3 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_3 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_3 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_3 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_3 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_3 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_3 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_3 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_3 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_3 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_3 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_3 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }


compat_event_subdevice_index_int_4 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_4 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_4 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_4 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_4 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_4 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_4 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_4 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_4 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_4 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_4 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_4 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_4 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_4 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_4 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_4 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_4 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_4 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_4 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_4 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_4 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_4 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_4 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_4 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_4 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_4 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii4 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event4 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_4 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_4 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_4 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_4 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_4 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_4 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_4 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_4 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_4 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_4 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_4 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_4 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_4 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_4 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_4 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_4 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_4 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_4 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_4 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_4 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_4 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_4 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_4 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_4 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_4 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_4 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_4 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_4 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_4 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_4 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_4 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_4 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_4 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_4 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_4 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }


compat_event_subdevice_index_int_5 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_5 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_5 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_5 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_5 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_5 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_5 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_5 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_5 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_5 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_5 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_5 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_5 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_5 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_5 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_5 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_5 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_5 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_5 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_5 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_5 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_5 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_5 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_5 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_5 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_5 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii5 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event5 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_5 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_5 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_5 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_5 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_5 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_5 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_5 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_5 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_5 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_5 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_5 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_5 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_5 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_5 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_5 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_5 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_5 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_5 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_5 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_5 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_5 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_5 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_5 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_5 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_5 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_5 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_5 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_5 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_5 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_5 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_5 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_5 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_5 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_5 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_5 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }


compat_event_subdevice_index_int_6 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_6 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_6 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_6 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_6 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_6 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_6 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_6 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_6 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_6 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_6 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_6 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_6 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_6 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_6 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_6 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_6 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_6 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_6 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_6 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_6 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_6 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_6 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_6 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_6 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_6 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii6 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event6 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_6 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_6 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_6 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_6 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_6 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_6 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_6 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_6 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_6 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_6 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_6 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_6 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_6 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_6 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_6 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_6 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_6 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_6 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_6 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_6 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_6 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_6 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_6 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_6 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_6 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_6 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_6 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_6 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_6 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_6 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_6 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_6 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_6 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_6 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_6 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }


compat_event_subdevice_index_int_7 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_7 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_7 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_7 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_7 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_7 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_7 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_7 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_7 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_7 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_7 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_7 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_7 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_7 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_7 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_7 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_7 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_7 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_7 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_7 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_7 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_7 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_7 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_7 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_7 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_7 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii7 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event7 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_7 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_7 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_7 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_7 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_7 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_7 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_7 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_7 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_7 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_7 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_7 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_7 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_7 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_7 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_7 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_7 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_7 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_7 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_7 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_7 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_7 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_7 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_7 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_7 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_7 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_7 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_7 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_7 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_7 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_7 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_7 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_7 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_7 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_7 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_7 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }

compat_event_subdevice_index_int_8 LIKE VARIABLE burst_subdevice_index1 { REDEFINE CLASS DEVICE; }
compat_event_subdevice_missing_8 LIKE VARIABLE subdevice_missing { REDEFINE CLASS DEVICE; }
compat_event_status_8 LIKE VARIABLE event_status { REDEFINE CLASS DEVICE; }
compat_event_notification_control_n_8 LIKE VARIABLE event_notification_control_n { REDEFINE CLASS DEVICE; }
compat_device_status_mask_8 LIKE VARIABLE device_status_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_mask_8 LIKE VARIABLE extended_fld_device_status_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_0_mask_8 LIKE VARIABLE standardized_status_0_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_1_mask_8 LIKE VARIABLE standardized_status_1_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_2_mask_8 LIKE VARIABLE standardized_status_2_mask { REDEFINE CLASS DEVICE; }
compat_standardized_status_3_mask_8 LIKE VARIABLE standardized_status_3_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_saturated1_mask_8 LIKE VARIABLE analog_channel_saturated1_mask { REDEFINE CLASS DEVICE; }
compat_analog_channel_fixed1_mask_8 LIKE VARIABLE analog_channel_fixed1_mask { REDEFINE CLASS DEVICE; }
compat_device_status_latched_value_8 LIKE VARIABLE device_status_latched_value { REDEFINE CLASS DEVICE; }
compat_dev_operating_mode_mask_8 LIKE VARIABLE dev_operating_mode_mask { REDEFINE CLASS DEVICE; }
compat_extended_fld_device_status_latched_value_8 LIKE VARIABLE extended_fld_device_status_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_0_latched_value_8 LIKE VARIABLE standardized_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_1_latched_value_8 LIKE VARIABLE standardized_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_2_latched_value_8 LIKE VARIABLE standardized_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_standardized_status_3_latched_value_8 LIKE VARIABLE standardized_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_saturated1_latched_value_8 LIKE VARIABLE analog_channel_saturated1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_analog_channel_fixed1_latched_value_8 LIKE VARIABLE analog_channel_fixed1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_dev_operating_mode_latched_value_8 LIKE VARIABLE dev_operating_mode_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_time_of_first_unack_event_8 LIKE VARIABLE time_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_event_notification_retry_time_event_8 LIKE VARIABLE event_notification_retry_time_event { REDEFINE CLASS DEVICE; }
compat_max_update_time_event_8 LIKE VARIABLE max_update_time_event { REDEFINE CLASS DEVICE; }
compat_event_debounce_interval_event_8 LIKE VARIABLE event_debounce_interval_event { REDEFINE CLASS DEVICE; }
time_of_first_unack_event_ascii8 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
date_of_first_unack_event8 LIKE VARIABLE date_of_first_unack_event { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_mask_8 LIKE VARIABLE device_specific_status_0_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_1_mask_8 LIKE VARIABLE device_specific_status_1_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_2_mask_8 LIKE VARIABLE device_specific_status_2_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_3_mask_8 LIKE VARIABLE device_specific_status_3_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_4_mask_8 LIKE VARIABLE device_specific_status_4_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_5_mask_8 LIKE VARIABLE device_specific_status_5_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_14_mask_8 LIKE VARIABLE device_specific_status_14_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_15_mask_8 LIKE VARIABLE device_specific_status_15_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_16_mask_8 LIKE VARIABLE device_specific_status_16_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_17_mask_8 LIKE VARIABLE device_specific_status_17_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_18_mask_8 LIKE VARIABLE device_specific_status_18_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_19_mask_8 LIKE VARIABLE device_specific_status_19_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_20_mask_8 LIKE VARIABLE device_specific_status_20_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_21_mask_8 LIKE VARIABLE device_specific_status_21_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_22_mask_8 LIKE VARIABLE device_specific_status_22_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_23_mask_8 LIKE VARIABLE device_specific_status_23_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_24_mask_8 LIKE VARIABLE device_specific_status_24_mask { REDEFINE CLASS DEVICE; }
compat_device_specific_status_0_latched_value_8 LIKE VARIABLE device_specific_status_0_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_1_latched_value_8 LIKE VARIABLE device_specific_status_1_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_2_latched_value_8 LIKE VARIABLE device_specific_status_2_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_3_latched_value_8 LIKE VARIABLE device_specific_status_3_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_4_latched_value_8 LIKE VARIABLE device_specific_status_4_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_5_latched_value_8 LIKE VARIABLE device_specific_status_5_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_14_latched_value_8 LIKE VARIABLE device_specific_status_14_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_15_latched_value_8 LIKE VARIABLE device_specific_status_15_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_16_latched_value_8 LIKE VARIABLE device_specific_status_16_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_17_latched_value_8 LIKE VARIABLE device_specific_status_17_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_18_latched_value_8 LIKE VARIABLE device_specific_status_18_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_19_latched_value_8 LIKE VARIABLE device_specific_status_19_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_20_latched_value_8 LIKE VARIABLE device_specific_status_20_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_21_latched_value_8 LIKE VARIABLE device_specific_status_21_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_22_latched_value_8 LIKE VARIABLE device_specific_status_22_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_23_latched_value_8 LIKE VARIABLE device_specific_status_23_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_device_specific_status_24_latched_value_8 LIKE VARIABLE device_specific_status_24_latched_value { REDEFINE CLASS DEVICE & DIAGNOSTIC; }
compat_config_change_counter_latched_value_8 LIKE VARIABLE config_change_counter_latched_value { REDEFINE CLASS DEVICE; }


COLLECTION OF VARIABLE compat_event_control_1
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_1,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_1,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_1,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_1,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_1,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_1,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_1,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_1,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii1,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event1,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_1
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_1;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_1;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_1; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_1;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_1; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_1; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_1;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_1;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_1;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_1;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_1;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_1;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_1;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_1;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_1;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_1;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_1;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_1;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_1;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_1;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_1;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_1;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_1;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_1;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_1;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_1;
    }
}

COLLECTION OF VARIABLE compat_event_report_1
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_1; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_1;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_1; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_1;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_1; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_1; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_1;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_1;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_1;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_1;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_1;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_1;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_1;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_1;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_1;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_1;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_1;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_1;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_1;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_1;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_1;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_1;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_1;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_1;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_1;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_1;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_1;       
    }
}


COLLECTION OF VARIABLE compat_event_control_2
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_2,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_2,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_2,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_2,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_2,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_2,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_2,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_2,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii2,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event2,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_2
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_2;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_2;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_2; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_2;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_2; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_2; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_2;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_2;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_2;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_2;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_2;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_2;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_2;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_2;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_2;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_2;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_2;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_2;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_2;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_2;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_2;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_2;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_2;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_2;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_2;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_2;
    }
}

COLLECTION OF VARIABLE compat_event_report_2
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_2; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_2;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_2; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_2;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_2; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_2; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_2;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_2;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_2;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_2;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_2;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_2;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_2;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_2;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_2;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_2;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_2;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_2;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_2;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_2;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_2;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_2;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_2;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_2;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_2;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_2;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_2;       
    }
}


COLLECTION OF VARIABLE compat_event_control_3
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_3,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_3,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_3,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_3,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_3,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_3,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_3,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_3,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii3,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event3,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_3
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_3;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_3;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_3; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_3;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_3; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_3; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_3;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_3;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_3;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_3;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_3;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_3;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_3;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_3;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_3;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_3;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_3;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_3;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_3;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_3;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_3;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_3;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_3;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_3;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_3;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_3;
    }
}

COLLECTION OF VARIABLE compat_event_report_3
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_3; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_3;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_3; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_3;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_3; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_3; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_3;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_3;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_3;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_3;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_3;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_3;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_3;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_3;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_3;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_3;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_3;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_3;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_3;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_3;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_3;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_3;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_3;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_3;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_3;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_3;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_3;       
    }
}


COLLECTION OF VARIABLE compat_event_control_4
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_4,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_4,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_4,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_4,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_4,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_4,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_4,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_4,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii4,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event4,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_4
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_4;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_4;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_4; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_4;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_4; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_4; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_4;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_4;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_4;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_4;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_4;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_4;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_4;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_4;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_4;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_4;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_4;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_4;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_4;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_4;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_4;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_4;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_4;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_4;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_4;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_4;
    }
}

COLLECTION OF VARIABLE compat_event_report_4
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_4; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_4;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_4; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_4;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_4; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_4; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_4;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_4;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_4;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_4;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_4;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_4;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_4;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_4;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_4;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_4;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_4;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_4;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_4;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_4;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_4;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_4;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_4;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_4;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_4;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_4;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_4;       
    }
}


COLLECTION OF VARIABLE compat_event_control_5
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_5,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_5,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_5,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_5,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_5,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_5,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_5,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_5,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii5,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event5,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_5
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_5;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_5;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_5; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_5;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_5; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_5; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_5;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_5;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_5;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_5;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_5;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_5;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_5;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_5;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_5;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_5;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_5;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_5;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_5;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_5;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_5;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_5;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_5;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_5;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_5;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_5;
    }
}

COLLECTION OF VARIABLE compat_event_report_5
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_5; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_5;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_5; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_5;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_5; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_5; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_5;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_5;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_5;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_5;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_5;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_5;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_5;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_5;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_5;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_5;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_5;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_5;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_5;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_5;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_5;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_5;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_5;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_5;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_5;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_5;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_5;       
    }
}


COLLECTION OF VARIABLE compat_event_control_6
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_6,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_6,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_6,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_6,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_6,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_6,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_6,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_6,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii6,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event6,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_6
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_6;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_6;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_6; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_6;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_6; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_6; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_6;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_6;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_6;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_6;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_6;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_6;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_6;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_6;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_6;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_6;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_6;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_6;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_6;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_6;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_6;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_6;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_6;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_6;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_6;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_6;
    }
}

COLLECTION OF VARIABLE compat_event_report_6
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_6; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_6;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_6; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_6;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_6; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_6; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_6;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_6;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_6;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_6;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_6;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_6;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_6;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_6;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_6;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_6;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_6;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_6;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_6;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_6;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_6;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_6;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_6;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_6;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_6;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_6;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_6;       
    }
}


COLLECTION OF VARIABLE compat_event_control_7
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_7,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_7,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_7,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_7,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_7,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_7,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_7,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_7,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii7,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event7,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_7
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_7;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_7;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_7; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_7;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_7; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_7; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_7;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_7;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_7;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_7;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_7;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_7;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_7;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_7;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_7;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_7;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_7;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_7;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_7;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_7;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_7;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_7;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_7;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_7;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_7;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_7;
    }
}

COLLECTION OF VARIABLE compat_event_report_7
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_7; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_7;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_7; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_7;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_7; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_7; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_7;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_7;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_7;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_7;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_7;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_7;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_7;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_7;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_7;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_7;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_7;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_7;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_7;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_7;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_7;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_7;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_7;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_7;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_7;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_7;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_7;       
    }
}


COLLECTION OF VARIABLE compat_event_control_8
{
    MEMBERS
    {
        EVENT_STATUS,                               compat_event_status_8,                             "Status";
        EVENT_NOTIFICATION_CONTROL,                 compat_event_notification_control_n_8,             "Event Notification Control";
        TIME_OF_FIRST_UNACK_EVENT,                  compat_time_of_first_unack_event_8,                "Event Time Stamp";
        EVENT_NOTIFICATION_RETRY_TIME,              compat_event_notification_retry_time_event_8,      "Retry Time";
        MAX_UPDATE_TIME,                            compat_max_update_time_event_8,                    "Max Update Time";
        EVENT_DEBOUNCE_INTERVAL,                    compat_event_debounce_interval_event_8,            "Debounce";
        SUB_DEVICE_MISSING,                         compat_event_subdevice_missing_8,                  "Sub device missing";
        SUB_DEVICE_MAPPING,                         compat_event_subdevice_index_int_8,                "Subdevice Tag";
        TIME_OF_FIRST_UNACK_EVENT_ASCII,            time_of_first_unack_event_ascii8,                  "Time of First Unack Event Triggered";
        DATE_OF_FIRST_UNACK_EVENT,                  date_of_first_unack_event8,                        "Date of First Unack Event Triggered";
    }
}

COLLECTION OF VARIABLE compat_event_mask_8
{
    MEMBERS
    {
        DEVICE_STATUS_MASK ,                        compat_device_status_mask_8;
        DEVICE_SPECIFIC_STATUS_0_MASK,              compat_device_specific_status_0_mask_8;
        DEVICE_SPECIFIC_STATUS_1_MASK,              compat_device_specific_status_1_mask_8; 
        DEVICE_SPECIFIC_STATUS_2_MASK,              compat_device_specific_status_2_mask_8;
        DEVICE_SPECIFIC_STATUS_3_MASK,              compat_device_specific_status_3_mask_8; 
        DEVICE_SPECIFIC_STATUS_4_MASK,              compat_device_specific_status_4_mask_8; 
        DEVICE_SPECIFIC_STATUS_5_MASK,              compat_device_specific_status_5_mask_8;

        EXTENDED_FLD_DEVICE_STATUS_MASK,            compat_extended_fld_device_status_mask_8;

        STANDARDIZED_STATUS_0_MASK,                 compat_standardized_status_0_mask_8;
        STANDARDIZED_STATUS_1_MASK,                 compat_standardized_status_1_mask_8;
        STANDARDIZED_STATUS_2_MASK,                 compat_standardized_status_2_mask_8;
        STANDARDIZED_STATUS_3_MASK,                 compat_standardized_status_3_mask_8;

        ANALOG_CHANNEL_FIXED1_MASK,                 compat_analog_channel_fixed1_mask_8;
        ANALOG_CHANNEL_SATURATED1_MASK,             compat_analog_channel_saturated1_mask_8;
        DEV_OPERATING_MODE_MASK,                    compat_dev_operating_mode_mask_8;

        DEVICE_SPECIFIC_STATUS_14_MASK,             compat_device_specific_status_14_mask_8;
        DEVICE_SPECIFIC_STATUS_15_MASK,             compat_device_specific_status_15_mask_8;
        DEVICE_SPECIFIC_STATUS_16_MASK,             compat_device_specific_status_16_mask_8;
        DEVICE_SPECIFIC_STATUS_17_MASK,             compat_device_specific_status_17_mask_8;
        DEVICE_SPECIFIC_STATUS_18_MASK,             compat_device_specific_status_18_mask_8;
        DEVICE_SPECIFIC_STATUS_19_MASK,             compat_device_specific_status_19_mask_8;
        DEVICE_SPECIFIC_STATUS_20_MASK,             compat_device_specific_status_20_mask_8;
        DEVICE_SPECIFIC_STATUS_21_MASK,             compat_device_specific_status_21_mask_8;
        DEVICE_SPECIFIC_STATUS_22_MASK,             compat_device_specific_status_22_mask_8;
        DEVICE_SPECIFIC_STATUS_23_MASK,             compat_device_specific_status_23_mask_8;
        DEVICE_SPECIFIC_STATUS_24_MASK,             compat_device_specific_status_24_mask_8;
    }
}

COLLECTION OF VARIABLE compat_event_report_8
{
    MEMBERS
    {
        DEVICE_STATUS_LATCHED_VALUE,                compat_device_status_latched_value_8; 
        DEVICE_SPECIFIC_STATUS_0_LATCHED_VALUE,     compat_device_specific_status_0_latched_value_8;
        DEVICE_SPECIFIC_STATUS_1_LATCHED_VALUE,     compat_device_specific_status_1_latched_value_8; 
        DEVICE_SPECIFIC_STATUS_2_LATCHED_VALUE,     compat_device_specific_status_2_latched_value_8;
        DEVICE_SPECIFIC_STATUS_3_LATCHED_VALUE,     compat_device_specific_status_3_latched_value_8; 
        DEVICE_SPECIFIC_STATUS_4_LATCHED_VALUE,     compat_device_specific_status_4_latched_value_8; 
        DEVICE_SPECIFIC_STATUS_5_LATCHED_VALUE,     compat_device_specific_status_5_latched_value_8;

        EXTENDED_FLD_DEVICE_STATUS_LATCHED_VALUE,   compat_extended_fld_device_status_latched_value_8;

        STANDARDIZED_STATUS_0_LATCHED_VALUE,        compat_standardized_status_0_latched_value_8;
        STANDARDIZED_STATUS_1_LATCHED_VALUE,        compat_standardized_status_1_latched_value_8;
        STANDARDIZED_STATUS_2_LATCHED_VALUE,        compat_standardized_status_2_latched_value_8;
        STANDARDIZED_STATUS_3_LATCHED_VALUE,        compat_standardized_status_3_latched_value_8;

        ANALOG_CHANNEL_SATURATED1_LATCHED_VALUE,    compat_analog_channel_saturated1_latched_value_8;
        ANALOG_CHANNEL_FIXED1_LATCHED_VALUE,        compat_analog_channel_fixed1_latched_value_8;
        DEV_OPERATING_MODE_LATCHED_VALUE,           compat_dev_operating_mode_latched_value_8;

        DEVICE_SPECIFIC_STATUS_14_LATCHED_VALUE,    compat_device_specific_status_14_latched_value_8;
        DEVICE_SPECIFIC_STATUS_15_LATCHED_VALUE,    compat_device_specific_status_15_latched_value_8;
        DEVICE_SPECIFIC_STATUS_16_LATCHED_VALUE,    compat_device_specific_status_16_latched_value_8;
        DEVICE_SPECIFIC_STATUS_17_LATCHED_VALUE,    compat_device_specific_status_17_latched_value_8;
        DEVICE_SPECIFIC_STATUS_18_LATCHED_VALUE,    compat_device_specific_status_18_latched_value_8;
        DEVICE_SPECIFIC_STATUS_19_LATCHED_VALUE,    compat_device_specific_status_19_latched_value_8;
        DEVICE_SPECIFIC_STATUS_20_LATCHED_VALUE,    compat_device_specific_status_20_latched_value_8;
        DEVICE_SPECIFIC_STATUS_21_LATCHED_VALUE,    compat_device_specific_status_21_latched_value_8;
        DEVICE_SPECIFIC_STATUS_22_LATCHED_VALUE,    compat_device_specific_status_22_latched_value_8;
        DEVICE_SPECIFIC_STATUS_23_LATCHED_VALUE,    compat_device_specific_status_23_latched_value_8;
        DEVICE_SPECIFIC_STATUS_24_LATCHED_VALUE,    compat_device_specific_status_24_latched_value_8;

        CONFIG_CHANGE_COUNTER_LATCHED_VALUE,        compat_config_change_counter_latched_value_8;       
    }
}


COLLECTION OF COLLECTION compat_event_1
{
    LABEL "Event 2";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_1;
        EVENT_MASK,         compat_event_mask_1;
        EVENT_REPORT,       compat_event_report_1;
    }
}


COLLECTION OF COLLECTION compat_event_2
{
    LABEL "Event 3";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_2;
        EVENT_MASK,         compat_event_mask_2;
        EVENT_REPORT,       compat_event_report_2;
    }
}

COLLECTION OF COLLECTION compat_event_3
{
    LABEL "Event 4";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_3;
        EVENT_MASK,         compat_event_mask_3;
        EVENT_REPORT,       compat_event_report_3;
    }
}

COLLECTION OF COLLECTION compat_event_4
{
    LABEL "Event 5";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_4;
        EVENT_MASK,         compat_event_mask_4;
        EVENT_REPORT,       compat_event_report_4;
    }
}

COLLECTION OF COLLECTION compat_event_5
{
    LABEL "Event 6";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_5;
        EVENT_MASK,         compat_event_mask_5;
        EVENT_REPORT,       compat_event_report_5;
    }
}

COLLECTION OF COLLECTION compat_event_6
{
    LABEL "Event 7";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_6;
        EVENT_MASK,         compat_event_mask_6;
        EVENT_REPORT,       compat_event_report_6;
    }
}

COLLECTION OF COLLECTION compat_event_7
{
    LABEL "Event 8";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_7;
        EVENT_MASK,         compat_event_mask_7;
        EVENT_REPORT,       compat_event_report_7;
    }
}

COLLECTION OF COLLECTION compat_event_8
{
    LABEL "Event 9";
    MEMBERS
    {
        EVENT_CONTROL,      compat_event_control_8;
        EVENT_MASK,         compat_event_mask_8;
        EVENT_REPORT,       compat_event_report_8;
    }
}


ARRAY OF COLLECTION compat_events
{
    LABEL "Events";
    ELEMENTS
    {
        0, event;
        1, compat_event_1;
        2, compat_event_2;
        3, compat_event_3;
        4, compat_event_4;
        5, compat_event_5;
        6, compat_event_6;
        7, compat_event_7;
        8, compat_event_8;
    }
}
#endif




VARIABLE device_description_version2
{
    LABEL "DD Version";
    HELP "The version number for the device description";
    CLASS LOCAL;
    TYPE FLOAT
    {
        DISPLAY_FORMAT "1.2f" ;
    }
    DEFAULT_VALUE DD_VERSION;
}


VARIABLE current_time1 
{
    LABEL "Current Time";
    HELP "Current Time based upon the real-time clock in the field device";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE ASCII(8);
}


VARIABLE last_clock_time1
{
    LABEL "Set Clock Time";
    HELP "Time to set the real time clock in the field device to, or time that the real-time clock was last set";
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ASCII(8);
}


VARIABLE software_build_date
{
    LABEL "Software Build Date";
    HELP "Software Build Date";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (20);
}


VARIABLE dust_software_major
{
    LABEL "Radio Software Rev Major";
    HELP "Radio Software Revision Major";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}


VARIABLE dust_software_minor
{
    LABEL "Radio Software Rev Minor";
    HELP "Radio Software Revision Minor";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}


VARIABLE dust_software_patch
{
    LABEL "Radio Software Rev Patch";
    HELP "Radio Software Revision Patch";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}


VARIABLE dust_software_build
{
    LABEL "Radio Software Rev Build";
    HELP "Radio Software Revision Build";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER(2);
}


VARIABLE software_revision_internal
{
    LABEL "Software Build";
    HELP "Software Build";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER(2);
}


VARIABLE software_bootloader_revision
{
    LABEL "Software Bootloader Revision";
    HELP "Internal Software Bootloader Revision";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}


VARIABLE device_serial_num
{
    LABEL "Device Serial Number";
    HELP "Device Serial Number";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (16);
}


VARIABLE device_model_num
{
    LABEL "Model Number";
    HELP "Model Number";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (16);
}


VARIABLE device_build_date
{
    LABEL "Production Date";
    HELP "Production Date";
    CLASS DEVICE;
    HANDLING READ;
    TYPE DATE;
}


VARIABLE device_lot_num
{
    LABEL "Lot Num";
    HELP "Lot Num";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (4);
}


VARIABLE device_mac_address
{
    LABEL "MAC Address";
    HELP "MAC Address";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (23);
}


VARIABLE system_uptime
{
    LABEL "System Uptime";
    HELP "Time in seconds since the system was powered on";
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    CONSTANT_UNIT [sec];
    TYPE UNSIGNED_INTEGER (4);
}


VARIABLE write_protect_mode
{
    LABEL "Write Protect";
    HELP "Write Protect";
    HANDLING READ & WRITE;
    CLASS DEVICE;
    TYPE ENUMERATED
    {
        { 0,   "Disabled" },
        { 1,   "Enabled" }
    }
}


VARIABLE user_password
{
    LABEL "User Password";
    HELP "User Password";
    HANDLING WRITE;
    TYPE PASSWORD (10) ;
}


VARIABLE license_key_ascii
{
    LABEL "License Key";
    HELP "License Key";
    CLASS DEVICE;
    HANDLING READ;
    TYPE ASCII (35);
}

VARIABLE license_key1
{
    LABEL "Key 1";
    HELP  "First key word for " DEVICE_NAME " License";
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE UNSIGNED_INTEGER (4)
    {
       DISPLAY_FORMAT "08X";
       EDIT_FORMAT "08X";
    }
    DEFAULT_VALUE 0;
}

VARIABLE license_key2
{
    LABEL "Key 2";
    HELP  "Second key word for " DEVICE_NAME " License";
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE UNSIGNED_INTEGER (4)
    {
       DISPLAY_FORMAT "08X";
       EDIT_FORMAT "08X";
    }
    DEFAULT_VALUE 0;
}

VARIABLE license_key3
{
    LABEL "Key 3";
    HELP  "Third key word for " DEVICE_NAME " License";
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE UNSIGNED_INTEGER (4)
    {
       DISPLAY_FORMAT "08X";
       EDIT_FORMAT "08X";
    }
    DEFAULT_VALUE 0;
}

VARIABLE license_key4
{
    LABEL "Key 4";
    HELP  "Fourth key word for " DEVICE_NAME " License";
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE UNSIGNED_INTEGER (4)
    {
       DISPLAY_FORMAT "08X";
       EDIT_FORMAT "08X";
    }
    DEFAULT_VALUE 0;
}


VARIABLE license_key_subdevices
{
    LABEL "Subdevices Supported";
    HELP  "The number of subdevices supported with this license key";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}


VARIABLE license_key_burst
{
    LABEL "Burst Messages Supported";
    HELP  "The number of burst messages supported with this license key";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}


VARIABLE license_key_event
{
    LABEL "Event Messages Supported";
    HELP  "The number of event messages supported with this license key";
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER;
}


VARIABLE license_key_power
{
    LABEL "Power Modes Supported";
    HELP  "The power modes supported with this license key";
    CLASS DEVICE;
    HANDLING READ;    
    TYPE BIT_ENUMERATED(2)
    {
        { 0x0008, "StepVolt Supported", DEVICE },
        { 0x0010, "Direct Power Supported", DEVICE },
        { 0x0100, "Integral Resistor Supported", DEVICE },
        { 0x0200, "Field Device Power Control Supported", DEVICE }
    }
}


METHOD set_license_key
{
    LABEL "Set License Key";
    HELP  "";
    DEFINITION 
    {
        char status[STATUS_SIZE];        
        int wReply;
        IGNORE_ALL_RESPONSE_CODES();
        IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_DEVICE_STATUS();

        do
        {    
            GET_DEV_VAR_VALUE("Enter the License Key:\n(part 1 of 4)", license_key1);
            GET_DEV_VAR_VALUE("Enter the License Key:\n(part 2 of 4)", license_key2);
            GET_DEV_VAR_VALUE("Enter the License Key:\n(part 3 of 4)", license_key3);
            GET_DEV_VAR_VALUE("Enter the License Key:\n(part 4 of 4)", license_key4);                

            wReply = SELECT_FROM_LIST("New License Key: %[08X]{license_key1}-%[08X]{license_key2}-%[08X]{license_key3}-%[08X]{license_key4}\n\n.","Accept new license key;Re-enter license key");

        } while( wReply != 0 );

        send(164,status);
        if (status[STATUS_RESPONSE_CODE]==0)
        {            
            // Update the count variables used by the burst, event and subdevice menus
            send(163,status);
            send(74,status);  
            send(138,status);  
            send_trans(105,0,status);  
            send_trans(193,0,status);   
            ACKNOWLEDGE("License Key Accepted");            
        }
        else
        {
            send(163,status);
            ACKNOWLEDGE("License Key Invalid");  
        }   
    }
}

COMMAND read_license_key
{
    NUMBER 163;
    OPERATION READ;
    TRANSACTION
    {     
        REQUEST
        {           
        }
        REPLY
        {
            response_code, device_status,
            license_key1, license_key2, license_key3, license_key4,
            license_key_subdevices, license_key_burst, license_key_event, license_key_power,
            license_key_ascii
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        6,  MISC_ERROR,       [xmtr_specific_command_error];
    }
}


COMMAND write_license_key
{
    NUMBER 164;
    OPERATION WRITE;
    TRANSACTION
    {     
        REQUEST
        {  
            license_key1, license_key2, license_key3, license_key4      
        }
        REPLY
        {
            response_code, device_status,
            license_key1, license_key2, license_key3, license_key4,
            license_key_subdevices, license_key_burst, license_key_event, license_key_power            
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        6,  MISC_ERROR,       [xmtr_specific_command_error];
    }
}


COMMAND read_real_time_clock_ascii
{
    NUMBER 190;
    OPERATION READ;
    TRANSACTION
    {     
        REQUEST
        {           
        }
        REPLY
        {
            response_code, device_status,
            current_date, current_time1, last_clock_date, 
            last_clock_time1, real_time_clock_flag
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        6,  MISC_ERROR,       [xmtr_specific_command_error];
        32, MODE_ERROR,       [busy];
        33, MODE_ERROR,       [delayed_response_initiated];
        34, MODE_ERROR,       [delayed_response_running];
        35, MODE_ERROR,       [delayed_response_dead];
        36, MODE_ERROR,       [delayed_response_conflict];
    }
}


COMMAND InternalSoftwareRevRead1
{
    NUMBER 168;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status,
            dummy_variable, software_revision_internal,
            dummy_variable, software_bootloader_revision, software_build_date,
            dummy_variable, dummy_variable, dummy_variable, dust_software_major, dust_software_minor,
            dust_software_patch, dust_software_build
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];        
        6,  MISC_ERROR, "Device Specific Command error";        
        16, MODE_ERROR, [access_restricted];
    }
}

COMMAND InternalSoftwareRevRead2
{
    NUMBER 169;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status,
            device_serial_num, device_model_num, device_build_date, device_lot_num
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];        
        6,  MISC_ERROR, "Device Specific Command error";        
        16, MODE_ERROR, [access_restricted];
    }
}


VARIABLE io_channel_parity_err_received
{
    LABEL "Parity Errors Received";
    HELP "Count of Parity Errors messages received by the I/O system on this channel";    
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER(2);
}

VARIABLE io_channel_framing_err_received
{
    LABEL "Framing Errors Received";
    HELP "Count of Framing Errors messages received by the I/O system on this channel";    
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER(2);
}

VARIABLE io_channel_checkbyte_err_received
{
    LABEL "CheckByte Errors Received";
    HELP "Count of CheckByte Errors messages received by the I/O system on this channel";    
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER(2);
}

VARIABLE io_channel_gap_err_received
{
    LABEL "Gap Errors Received";
    HELP "Count of Gap Errors messages received by the I/O system on this channel";    
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER(2);
}


COMMAND read_io_channel_stats_extended   
{
    NUMBER 174;
    OPERATION READ;
    TRANSACTION 0
    {
        REQUEST
        {
            0,
            0
        }
        REPLY
        {
            response_code, device_status,
            0,
            0,
            io_channel_stx_sent,
            io_channel_ack_received,
            io_channel_ostx_received,
            io_channel_oack_received,
            io_channel_back_received,
            io_channel_parity_err_received,
            io_channel_framing_err_received,
            io_channel_checkbyte_err_received,
            io_channel_gap_err_received
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR, [invalid_selection];
        5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
        6,  MISC_ERROR,       [xmtr_specific_command_error];
        21, DATA_ENTRY_ERROR, "Invalid I/O card number";
        22, DATA_ENTRY_ERROR, "Invalid channel number";
        32, MODE_ERROR,       [busy];
    }
}


COMMAND SystemUptimeRead
{
    NUMBER 138;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status, system_uptime, subdevice_count   
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        6,  MISC_ERROR, "Device Specific Command error";       
        16, MODE_ERROR, [access_restricted];
    }
}


COMMAND MacAddressRead
{
    NUMBER 140;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status, device_mac_address
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        6,  MISC_ERROR, "Device Specific Command error";       
        16, MODE_ERROR, [access_restricted];
    }
}


COMMAND ResetToFactory
{
    NUMBER 141;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST
        {
            user_password
        }
        REPLY
        {
            response_code, device_status
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        5,  MISC_ERROR, "reset_specific_command_error";
        7,  MODE_ERROR, [in_write_protect_mode];
        12, MISC_ERROR, "Invalid Password";
        16, MODE_ERROR, [access_restricted];
        32, MODE_ERROR, [busy];
    }
}


COMMAND WriteProtectRead
{
    NUMBER 142;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status, write_protect_mode   
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        6,  MISC_ERROR, "Device Specific Command error";       
        16, MODE_ERROR, [access_restricted];
    }
}


COMMAND WriteProtectWrite
{
    NUMBER 143;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            write_protect_mode
        }
        REPLY
        {
            response_code, device_status, write_protect_mode   
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR, "Too few data bytes received";
        6,  MISC_ERROR, "Device Specific Command error";       
        16, MODE_ERROR, [access_restricted];
    }
}


COMMAND WirelessInternalStatus
{
    NUMBER 150;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status, 
            dummy_variable, wireless_duty_cycle, 
            dummy_variable, burst_service_time, burst_service_granted, burst_service_requested, 
            dummy_variable, dummy_variable, dummy_variable, dummy_variable, dummy_variable, dummy_variable, 
            dummy_variable, dummy_variable, dummy_variable, dummy_variable, dummy_variable, dummy_variable, 
            last_join_time    
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        6,  MISC_ERROR, "Device Specific Command error";       
        16, MODE_ERROR, [access_restricted];
    }
}


METHOD factoryResetMethod
{
    LABEL "Factory reset";
    HELP  "";
    DEFINITION 
    {
        char status[STATUS_SIZE];
        char xmtr_status[MAX_XMTR_STATUS_LEN];
        char disp_string1[60];             
        long x;
        int number_of_tries;
        int slen1;

        slen1 = 60;
        
        IGNORE_ALL_RESPONSE_CODES();
        IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_DEVICE_STATUS();

        GET_DEV_VAR_VALUE("Enter Factory Reset Password ", user_password);

        send(141,status);
    
        if (status[STATUS_RESPONSE_CODE])
        {
           display_response_status(141, status[STATUS_RESPONSE_CODE]);   
           process_abort();        /* this will call return_to_normal */
        }

        send(42,status);
        if (status[STATUS_RESPONSE_CODE])
        {
           display_response_status(42, status[STATUS_RESPONSE_CODE]);           
        }
        DELAY_TIME(6);

        RETRY_ON_NO_DEVICE();
        number_of_tries = 0;

        do 
        {
            get_more_status(status, xmtr_status);
        } while (((status[STATUS_RESPONSE_CODE] == DEVICE_BUSY) )                
                && (number_of_tries++ < MAXIMUM_RESET_RETRIES));

        if ((status[STATUS_RESPONSE_CODE] == DEVICE_BUSY)
                || (status[STATUS_RESPONSE_CODE] == UPDATE_IN_PROGRESS))
        {
            get_dictionary_string(device_stuck_in_device_reset, disp_string1, slen1);
            ACKNOWLEDGE(disp_string1);
        }
        else if (status[STATUS_RESPONSE_CODE])
        {
            display_response_status(48, status[STATUS_RESPONSE_CODE]);
            get_dictionary_string(abort_last_error, disp_string1, slen1);             
            DELAY(2, disp_string1);
        }
        else
        {
            // Need to read out everything that changed
            send(144,status);       // Get Burst Auto Mode
            send(128,status);       // Get Power Mode
            send(74,status);        // Get Master Mode, Retries
            send(7,status);         // Get Polling Addr
            send(142,status);       // Get Write Protect
            send(134,status);       // Get Polling Addr Scan Start, Stop, power-up enab, Time sync            
            send(159,status);       // Get Dust OTAP Setting
            send(146,status);       // Get Loop Switch Parameters

            send(772,status);       // Get Join Mode
            send(774,status);       // Get Network ID            
            send(798,status);       // Get Wireless TX Power

            send(0,status);         // Get Preamble response count
            loop_power_mode = 0;
            adapter_power = 0;
            send(129,status);
            if(status[STATUS_RESPONSE_CODE])
            {
                display_response_status(129, status[STATUS_RESPONSE_CODE]);
                get_dictionary_string(abort_last_error, disp_string1, slen1);             
                DELAY(2, disp_string1);
                process_abort();
            }
            send(147,status);
            if(status[STATUS_RESPONSE_CODE])
            {
                display_response_status(147, status[STATUS_RESPONSE_CODE]);
                get_dictionary_string(abort_last_error, disp_string1, slen1);             
                DELAY(2, disp_string1);
                process_abort();
            }
	   
            ACKNOWLEDGE("System Restored to Factory Defaults");
        }

        process_abort();        /* this will call return_to_normal */
    }
}


METHOD device_master_reset 
{
    LABEL "Perform Master Reset";
    HELP [device_reset_help];
    DEFINITION 
    {
        char status[STATUS_SIZE];
        char xmtr_status[MAX_XMTR_STATUS_LEN];
        char disp_string1[60];             
        long x;
        int number_of_tries;
        int slen1;

        slen1 = 60;

        IGNORE_ALL_RESPONSE_CODES();
        IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_DEVICE_STATUS();

        get_dictionary_string(remove_loop_from_auto, disp_string1, slen1); 
        ACKNOWLEDGE(disp_string1);
        add_abort_method(return_to_normal);

        get_dictionary_string(about_to_perform_device_reset, disp_string1, slen1);
        ACKNOWLEDGE(disp_string1);

        get_dictionary_string(device_reset_in_progress, disp_string1, slen1);
        PUT_MESSAGE(disp_string1);

        send(42, status);

        if(status[STATUS_RESPONSE_CODE])
        {
            display_response_status(42, status[STATUS_RESPONSE_CODE]);
            get_dictionary_string(abort_last_error, disp_string1, slen1);             
            DELAY(2, disp_string1);
            process_abort();
        }
        RETRY_ON_NO_DEVICE();
        number_of_tries = 0;

        get_dictionary_string(device_reset_in_progress, disp_string1, slen1);
        DELAY_TIME(5);

     do 
        {
            get_more_status(status, xmtr_status);
        } while (((status[STATUS_RESPONSE_CODE] == DEVICE_BUSY) )                
                && (number_of_tries++ < MAXIMUM_RESET_RETRIES));

        if ((status[STATUS_RESPONSE_CODE] == DEVICE_BUSY)
                || (status[STATUS_RESPONSE_CODE] == UPDATE_IN_PROGRESS))
        {
            get_dictionary_string(device_stuck_in_device_reset, disp_string1, slen1);
            ACKNOWLEDGE(disp_string1);
        }
        else if (status[STATUS_RESPONSE_CODE])
        {
            display_response_status(48, status[STATUS_RESPONSE_CODE]);
            get_dictionary_string(abort_last_error, disp_string1, slen1);             
            DELAY(2, disp_string1);
        }
        else if (xmtr_status[0])
        {
            for (x=1; x < 0x100; x <<= 1)
            {
                if (xmtr_status[0] & x)
                {
                    display_xmtr_status(device_specific_status_0, x);
                }
            }
        }
        else
        {
            get_dictionary_string(device_reset_ok, disp_string1, slen1);
            ACKNOWLEDGE(disp_string1);
        }

        process_abort();        /* this will call return_to_normal */
    }
}


IMAGE device_icon
{
    PATH "e0ac_device_icon.gif";
}


IMAGE adapter_pict
{
    PATH "e0ac_adapter.gif";
}


IMAGE alert_status_image
{    
    LABEL "Device Status";
    HELP "Device Status";   

    PATH IF(( extended_fld_device_status & 0x01 ) == 0)
    {
        "e0ac_good.gif";
    }
    ELSE 
    {
        "e0ac_alerts_exist.gif";        
    } 

    LINK alerts_dialog;   
}


IMAGE wireless_status_image
{    
    PATH IF( ( wireless_mode == 0) || ( wireless_mode==6 ) )
    {
       "e0ac_idle.gif";
    }
    ELSE 
    {
        IF(join_status < 0x0010)
        {
            "e0ac_searching.gif";
        }
        ELSE
        { 
            IF(join_status & 0x040)
            {
                "e0ac_join_failed.gif";
            }
            ELSE 
            {
                IF(join_status < 0x400 )
                {
                    "e0ac_joining.gif";
                }
                ELSE
                {
                    "e0ac_joined.gif";
                }
            }
        }
    }
    LINK wireless_status_dlg;
}




MENU device_root_menu
{
    LABEL "Configure";
    STYLE MENU;
    ITEMS
    {
        guided_setup,           // menu 
        manual_setup            // menu 
    }
}


MENU device_configure_menu
{
    LABEL "Configure";
    STYLE MENU;
    ITEMS
    {
        guided_setup,           // menu 
        manual_setup            // menu 
    }
}



MENU process_variables_root_menu
{
    LABEL "Overview";
    STYLE MENU;
    ITEMS
    {
        overview
    }
}


MENU diagnostic_root_menu
{
    LABEL "Service Tools";
    STYLE MENU;
    ITEMS
    {       
        alerts,        
        status_display,     
        power_time,
        communications,          // menu
        maintenance,             // menu 
        time,                    // menu
        simulate                 // menu        
    }
}


MENU device_info_dialog
{
    LABEL "Device Information";
    STYLE DIALOG;
    ITEMS
    {
        device_info_tab1,
        device_info_tab2,
        device_info_tab3
    }
}

MENU device_info_tab1
{
    LABEL "Device Information";
    STYLE PAGE;
    ITEMS
    {
        device_info_tab1_group1,    
        device_info_tab1_group2,
        device_info_tab2_group5,
        COLUMNBREAK        
        adapter_pict(INLINE)       
    }
}

MENU device_info_tab1_group1
{
    LABEL "Identification";
    STYLE GROUP;
    ITEMS
    {
        tag (DISPLAY_VALUE, READ_ONLY),
        longTag(DISPLAY_VALUE, READ_ONLY),        
        final_assembly_number (DISPLAY_VALUE, READ_ONLY)        
    }
}


MENU device_info_tab1_group2
{
    LABEL "Device Identification";
    STYLE GROUP;
    ITEMS
    {
        manufacturer_id (DISPLAY_VALUE, READ_ONLY),
        device_type (DISPLAY_VALUE, READ_ONLY),
        device_mac_address(DISPLAY_VALUE, READ_ONLY),         
        device_serial_num(DISPLAY_VALUE, READ_ONLY),
        device_id (DISPLAY_VALUE, READ_ONLY)
    }
}


MENU device_info_tab2
{
    LABEL "Extended Information";
    STYLE PAGE;
    ITEMS
    {
        device_info_tab2_group1,    
        device_info_tab2_group3,
        COLUMNBREAK,
        device_info_tab2_group2,
        device_info_tab2_group4        
    }
}


MENU device_info_tab2_group1
{
    LABEL "Model Information";
    STYLE GROUP;
    ITEMS
    {
        manufacturer_id (DISPLAY_VALUE, READ_ONLY),
        device_type (DISPLAY_VALUE,READ_ONLY),
        device_model_num(DISPLAY_VALUE,READ_ONLY),
        device_build_date(DISPLAY_VALUE, READ_ONLY),
        device_lot_num(DISPLAY_VALUE, READ_ONLY)   
    }
}


MENU device_info_tab2_group2
{
    LABEL "Information";
    STYLE GROUP;
    ITEMS
    {
        date (DISPLAY_VALUE, READ_ONLY),
        descriptor (DISPLAY_VALUE, READ_ONLY),
        message (DISPLAY_VALUE, READ_ONLY),                   
        country_code (DISPLAY_VALUE,READ_ONLY),
        si_control (DISPLAY_VALUE, READ_ONLY),        
        write_protect_mode (DISPLAY_VALUE, READ_ONLY)
    }
}

MENU device_info_tab2_group3
{
    LABEL "Revision Numbers";
    STYLE GROUP;
    ITEMS
    {
        universal_revision (DISPLAY_VALUE, READ_ONLY),        
        transmitter_revision (DISPLAY_VALUE, READ_ONLY),
        software_revision (DISPLAY_VALUE, READ_ONLY),
        hardware_revision (DISPLAY_VALUE, READ_ONLY)
    }
}


MENU device_info_tab2_group4
{
    LABEL "Software Revision";
    STYLE GROUP;
    ITEMS
    {
        software_revision_internal (DISPLAY_VALUE, READ_ONLY),
        software_bootloader_revision (DISPLAY_VALUE, READ_ONLY),
        software_build_date(DISPLAY_VALUE, READ_ONLY)
    }
}


MENU device_info_tab2_group5
{
    LABEL "DD Version";
    STYLE GROUP;
    ITEMS
    {
        device_description_version2 (DISPLAY_VALUE, READ_ONLY)
    }
}


MENU device_info_tab3
{
    LABEL "Wireless";
    STYLE PAGE;
    ITEMS
    {
        device_info_tab3_group1,
        COLUMNBREAK,
        device_info_tab3_group2        
    }
}

MENU device_info_tab3_group1
{
    LABEL "Wireless Module";
    STYLE GROUP;
    ITEMS
    {
        wireless_module_manufacturer_id(DISPLAY_VALUE),        
        wireless_module_device_type(DISPLAY_VALUE),            
        wireless_module_transmitter_revision(DISPLAY_VALUE),            
        wireless_module_software_revision(DISPLAY_VALUE),
        wireless_module_hardware_revision(DISPLAY_VALUE) 
    }
}


MENU device_info_tab3_group2
{
    LABEL "Radio Software";
    STYLE GROUP;
    ITEMS
    {
        dust_software_major(DISPLAY_VALUE),
        dust_software_minor(DISPLAY_VALUE),
        dust_software_patch(DISPLAY_VALUE),
        dust_software_build(DISPLAY_VALUE)   
    }
}


MENU overview
{
    LABEL "Overview";
    STYLE WINDOW;
    ITEMS
    {              
        overview_page
    }
}


MENU overview_page
{
    LABEL "Overview";
    STYLE PAGE;
    ITEMS
    {              
        adapter_pict(INLINE),
        COLUMNBREAK    
        overview_pv,    
        COLUMNBREAK    
        overview_status1,
        overview_status2,
        COLUMNBREAK
        ROWBREAK        
     
        IF ( subdevice_count == 0x0000 ) 
        {
            sub_device_menu_display_none,
            ROWBREAK
        }        
        IF ( subdevice_count > 0x0000 ) 
        {
            sub_device_menu_display_1,
            ROWBREAK
        }
        IF ( subdevice_count > 0x0001 ) 
        {
            sub_device_menu_display_2,
            ROWBREAK
        }
        IF ( subdevice_count > 0x0002 ) 
        {
            sub_device_menu_display_3,
            ROWBREAK
        }
        IF ( subdevice_count > 0x0003 ) 
        {
            sub_device_menu_display_4,
            ROWBREAK
        }
        IF ( subdevice_count > 0x0004 ) 
        {
            sub_device_menu_display_5,
            ROWBREAK
        }
        IF ( subdevice_count > 0x0005 ) 
        {
            sub_device_menu_display_6,
            ROWBREAK
        }
        IF ( subdevice_count > 0x0006 ) 
        {
            sub_device_menu_display_7,
            ROWBREAK
        }
        IF ( subdevice_count > 0x0007 ) 
        {
            sub_device_menu_display_8,
            ROWBREAK
        }

        IF( subdevice_count == 0x0000 )  
        {
            " ",
            " ",
            " ",            
            ROWBREAK
        }

        IF( subdevice_count == 0x0001 )  
        {
            " ",
            " ",
            " ",            
            ROWBREAK
        }

        IF( subdevice_count == 0x0002 )  
        {
            " ",            
            ROWBREAK
        }
        overview_shortcut        
    }
}


MENU overview_pv
{
    LABEL DEVICE_NAME " Status";
    STYLE GROUP;
    ITEMS
    {   
        wireless_mode (DISPLAY_VALUE),        
        PV.DAQ.ANALOG_VALUE(DISPLAY_VALUE),     
        PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),                       
        var1_value(DISPLAY_VALUE, READ_ONLY),        
        var2_value(DISPLAY_VALUE, READ_ONLY)                              
    }
}


MENU overview_status1
{
    LABEL "Device Status";
    STYLE GROUP;
    ITEMS
    {        
        alert_status_image(INLINE)
    }
}

MENU overview_status2
{
    LABEL "Wireless Status";
    STYLE GROUP;
    ITEMS
    {
        wireless_status_image(INLINE)        
        
    }
}


MENU overview_shortcut
{
    LABEL "Shortcuts";
    STYLE GROUP;
    ITEMS
    {
        device_info_dialog,         
        COLUMNBREAK,        
        adapter_config_power,  
        COLUMNBREAK,      
        join_network
    }
}


MENU configure
{
    LABEL "Configure";
    STYLE MENU;
    ITEMS
    {
        guided_setup,           // menu 
        manual_setup            // menu 
    }
}


MENU service_tools
{
    LABEL "Service Tools";
    STYLE MENU;
    ITEMS
    {           
        alerts,        
        status_display,     
        power_time,
        communications,          // menu
        maintenance,             // menu 
        time,                    // menu
        simulate                 // menu
    }
}


MENU communications
{
    LABEL "Communications";
    STYLE WINDOW;   
    ITEMS
    {        
        wireless_status,             
        wireless_statistics,
        message_statistics
    }
}


MENU maintenance
{
    LABEL "Maintenance";
    STYLE WINDOW; 
    ITEMS
    {
        maintenance_page
    }
}

MENU maintenance_page
{
    LABEL "Maintenance";
    STYLE PAGE; 
    ITEMS
    {
        maintenance_group1,
        maintenance_group2,
        maintenance_group3,
        maintenance_group5,
        maintenance_group6,
        maintenance_group7
    }
}


MENU maintenance_group1
{
    LABEL "Master Reset";
    STYLE GROUP; 
    ITEMS
    {
        device_master_reset,                                          // method
        COLUMNBREAK,
        "Resets the " DEVICE_NAME 
    }
}


MENU maintenance_group2
{
    LABEL "Self Test";
    STYLE GROUP; 
    ITEMS
    {
        device_self_test,                                          // method
        COLUMNBREAK,
        "Perform a self test on the " DEVICE_NAME
    }
}


MENU maintenance_group3
{
    LABEL "Factory Reset";
    STYLE GROUP; 
    ITEMS
    {
        factoryResetMethod,                                          // method
        COLUMNBREAK,
        "Resets the "DEVICE_NAME " back to the factory default\nconfiguration"
    }
}


MENU maintenance_group5
{
    LABEL "Advertise to New Devices";
    STYLE GROUP; 
    ITEMS
    {
        active_advertising,                                          // method
        COLUMNBREAK,
        "Advertise to new WirelessHART devices trying\nto join this network"
    }
}


MENU maintenance_group6
{
    LABEL "Calibrate";
    STYLE GROUP; 
    ITEMS
    {
        adapter_loop_cal,                                          // method
        COLUMNBREAK,
        "Calibrate the Loop Current reading of the " DEVICE_NAME
    }
}


MENU maintenance_group7
{
    LABEL "Internal";
    STYLE GROUP; 
    ITEMS
    {
        var3_value(DISPLAY_VALUE)
    }
}


MENU simulate
{
    LABEL "Simulate";
    STYLE WINDOW; 
    ITEMS
    {
        simulate_page 
    }
}

MENU simulate_page
{
    LABEL "Simulate";
    STYLE PAGE; 
    ITEMS
    {
        simulate_group1,     
        simulate_group2,     
        simulate_group3     
    }
}


MENU simulate_group1
{
    LABEL "Simulate Loop Current";
    STYLE GROUP; 
    ITEMS
    {
        device_simulate_loop_current,                                          // method
        COLUMNBREAK,
        "Simulate the loop current reading of the " DEVICE_NAME
    }
}


MENU simulate_group2
{
    LABEL "Simulate Direct Power";
    STYLE GROUP; 
    ITEMS
    {
        device_simulate_direct_power,                                          // method
        COLUMNBREAK,
        "Simulate the direct power reading of the " DEVICE_NAME
    }
}


MENU simulate_group3
{
    LABEL "Simulate Electronics Temperature";
    STYLE GROUP; 
    ITEMS
    {
        device_simulate_temperature,                                          // method
        COLUMNBREAK,
        "Simulate the electronics temperature reading of the " DEVICE_NAME
    }
}


MENU guided_setup
{
    LABEL "Guided Setup";
    STYLE WINDOW;
    ITEMS
    {
        guided_setup_page
    }
}

MENU guided_setup_page
{
    LABEL "Guided Setup";
    STYLE PAGE;
    ITEMS
    {
        guided_setup1,
        guided_setup2
    }
}


MENU guided_setup1
{
    LABEL "Power";
    STYLE GROUP;
    ITEMS
    {
        adapter_config_power,   // method  
        COLUMNBREAK,
        "Set the " DEVICE_NAME " Power Configuration"        
    }
}


MENU guided_setup2
{
    LABEL "Wireless";
    STYLE GROUP;
    ITEMS
    {
        join_network,               // method
        COLUMNBREAK,
        "Set Network ID and Join Key for the WirelessHART network"
    }
}


MENU manual_setup
{
    LABEL "Manual Setup";
    STYLE WINDOW;
    ITEMS
    {
        manual_setup_power,
        manual_setup_wireless,      
        manual_setup_wired, 
        manual_setup_4_20_ma,
        manual_setup_burst1,
        manual_setup_burst2,         
        manual_setup_burst3,      
        manual_setup_event1,
        manual_setup_event2,       
        manual_setup_device        
    }
}


MENU manual_setup_wireless
{
    LABEL "Wireless";
    STYLE PAGE;
    ITEMS
    {
        manual_setup_wireless_group1,
        manual_setup_wireless_group2        
    }
}


MENU manual_setup_wireless_group1
{
    LABEL "Wireless";
    STYLE GROUP;
    ITEMS
    {
        network_id (DISPLAY_VALUE),            
        join_mode (DISPLAY_VALUE), 
        radio_power_output1 (DISPLAY_VALUE),
        COLUMNBREAK,
        "",
        join_network,
        disconnect_network
    }
}

MENU manual_setup_wireless_group2
{
    LABEL "Radio Upgrade";
    STYLE GROUP;
    ITEMS
    {
        dust_otap_setting (DISPLAY_VALUE),            
        COLUMNBREAK,
        "Enable the " DEVICE_NAME " radio module to be upgraded using\nover the air programming"        
    }
}

MENU manual_setup_burst1
{
    LABEL "Burst Settings";
    STYLE PAGE;
    ITEMS
    {
        manual_setup_burst1_group1, 
        burst_menu_0,
        burst_menu_1,
        burst_menu_2,   
        burst_menu_3,   
        burst_menu_4,   
        burst_menu_5, 
        burst_menu_update        
    }
}


MENU manual_setup_burst2
{
    LABEL "Burst Settings 2";
    STYLE PAGE;
    VALIDITY  IF ( license_key_burst > 0x0006 )   {TRUE;}   ELSE  {FALSE;}    
    ITEMS
    { 
        burst_menu_6,
        burst_menu_7,   
        burst_menu_8,   
        burst_menu_9,        
        burst_menu_10,
        burst_menu_11  
    }
}


MENU manual_setup_burst3
{
    LABEL "Burst Settings 3";
    STYLE PAGE;
    VALIDITY  IF ( license_key_burst > 0x000C )   {TRUE;}   ELSE  {FALSE;}    
    ITEMS
    { 
        burst_menu_12,
        burst_menu_13,
        burst_menu_14,   
        burst_menu_15,   
        burst_menu_16,        
        burst_menu_17        
    }
}


MENU manual_setup_event1
{
    LABEL "Event Notification";
    STYLE PAGE;
    ITEMS
    {         
        event_menu_event0,
        event_menu_event1,
        event_menu_event2,
        event_menu_event3,
        event_menu_event4
    }
}


MENU manual_setup_event2
{
    LABEL "Event Notification 2";
    STYLE PAGE;
    VALIDITY  IF ( license_key_event > 0x0005 )   {TRUE;}   ELSE  {FALSE;}    
    ITEMS
    { 
        event_menu_event5,
        event_menu_event6,
        event_menu_event7,
        event_menu_event8 
    }
}


MENU manual_setup_burst1_group1
{
    LABEL "Auto Burst";
    STYLE GROUP;
    ITEMS
    {
        auto_burst_mode (DISPLAY_VALUE),
        auto_burst_type (DISPLAY_VALUE),
        COLUMNBREAK,
        "\nSet the automatic burst settings"
    }
}


MENU manual_setup_power
{
    LABEL "Power";
    STYLE PAGE;
    ITEMS
    {
        manual_setup_power_group1,
        manual_setup_power_group2,      
        manual_setup_power_group3        
        manual_setup_power_group4        
    }
}

MENU manual_setup_power_group1
{
    LABEL "Guided Power Settings";
    STYLE GROUP;
    ITEMS
    {                     
        adapter_config_power
        COLUMNBREAK,
        "Guided method to configure power settings"
    }
}


MENU manual_setup_power_group2
{
    LABEL DEVICE_NAME " Power Setting";
    STYLE GROUP;
    ITEMS
    {                     
        adapter_power (DISPLAY_VALUE),                
        COLUMNBREAK,        
        "Set the " DEVICE_NAME " Power Mode:\n      Loop Power: Choose the highest voltage step possible\n      Direct Power: Choose the setting based on available power"
    }
}

MENU manual_setup_power_group3
{
    LABEL "Field Device Power Control";
    STYLE GROUP;
    ITEMS
    {   
        loop_power_mode (DISPLAY_VALUE),     
        loop_turn_on_time (DISPLAY_VALUE),                
        loop_idle_time(DISPLAY_VALUE),
        loop_connect_estimated_percent(DISPLAY_VALUE),
        loop_switch_cutoff_en(DISPLAY_VALUE),
        loop_switch_cutoff_voltage(DISPLAY_VALUE),

        "NOTE: These settings are only used when the device\nis wired in the Field Device Power Control Configuration",
        COLUMNBREAK,
        "\nSet the Field Device Power Control Setting\n\nSet the Field Device turn on time\n\nSet the time the Field Device remains powered when\nan external HART master is detected\n\n\n\nEnable the Field Device Cutoff\n\nSet the Field Device Cutoff Voltage"         
    }
}


MENU manual_setup_power_group4
{
    LABEL "External Battery";   
    VALIDITY  IF ( hardware_revision >= 2 )   {TRUE;}   ELSE  {FALSE;}    
    STYLE GROUP;
    ITEMS
    {   
        battery_capacity(DISPLAY_VALUE),
        battery_low_voltage(DISPLAY_VALUE),
        battery_critical_voltage(DISPLAY_VALUE),
        COLUMNBREAK,
        "\nSet the Battery Capacity\n\nSet the Battery Low Voltage\n\nSet the Battery Critical Power Voltage",  
        clear_battery_counters
    }
}


MENU manual_setup_power_status_group1
{
    LABEL "Field Device Power Control Settings";
    STYLE GROUP;
    ITEMS
    {   
        loop_power_mode (DISPLAY_VALUE, READ_ONLY),     
        loop_turn_on_time (DISPLAY_VALUE, READ_ONLY),                
        loop_idle_time(DISPLAY_VALUE,READ_ONLY),
        loop_connect_estimated_percent(DISPLAY_VALUE)
    }
}


MENU manual_setup_power_status_group2
{
    LABEL "Field Device Power Control Stats";
    STYLE GROUP;
    ITEMS
    {   
        loop_connect_on_time(DISPLAY_VALUE),
        loop_connect_off_time(DISPLAY_VALUE),
        loop_connect_on_percent(DISPLAY_VALUE)
             
    }
}


MENU manual_setup_power_status_group3
{
    LABEL "External Battery Settings";  
    VALIDITY  IF ( hardware_revision >= 2 )   {TRUE;}   ELSE  {FALSE;}    
    STYLE GROUP;  
    ITEMS
    {   
        battery_capacity(DISPLAY_VALUE, READ_ONLY),
        battery_low_voltage(DISPLAY_VALUE, READ_ONLY),
        battery_critical_voltage(DISPLAY_VALUE, READ_ONLY)
    }
}


MENU manual_setup_power_status_group4
{
    LABEL "External Battery Stats";  
    VALIDITY  IF ( hardware_revision >= 2 )   {TRUE;}   ELSE  {FALSE;}    
    STYLE GROUP;  
    ITEMS
    {   
        device_power_status (DISPLAY_VALUE, READ_ONLY),     
        battery_life (DISPLAY_VALUE, READ_ONLY),                
        battery_coulomb_curr_rate(DISPLAY_VALUE,READ_ONLY),
        battery_coulomb_total(DISPLAY_VALUE,READ_ONLY),
        battery_coulomb_remain(DISPLAY_VALUE,READ_ONLY),
        battery_change_date(DISPLAY_VALUE,READ_ONLY)
    }
}


MENU manual_setup_wired
{
    LABEL "Wired";
    STYLE PAGE;
    ITEMS
    {
        manual_setup_other_group2,
        manual_setup_wired_group1,
        manual_setup_wired_group2,
        manual_setup_other_group1
    }
}


MENU manual_setup_wired_group1
{
    LABEL "Device Scan Mode";
    STYLE GROUP;
    ITEMS
    {   
        sub_device_powerUp_scan (DISPLAY_VALUE),
        poll_addr_start(DISPLAY_VALUE),
        poll_addr_stop(DISPLAY_VALUE),                
        COLUMNBREAK,
        "Set the " DEVICE_NAME " to scan for wired devices\non power up or reset",        
        "",        
        scan_subdevices
    }
}
       

MENU manual_setup_wired_group2
{
    LABEL "Sub-device Time Sync";
    STYLE GROUP;
    ITEMS
    {   
        sub_device_time_sync_en(DISPLAY_VALUE),        
        COLUMNBREAK,
        "Set to the allow the " DEVICE_NAME " to synchronize wired devices to\nthe WirelessHART time if the device supports a clock"
    }
}


MENU manual_setup_device
{
    LABEL DEVICE_NAME " Information";
    STYLE PAGE;
    ITEMS
    {
        manual_setup_device_group1,
        manual_setup_device_group2,
        COLUMNBREAK,
        device_info_dialog       
    }
}


MENU manual_setup_device_group1
{
    LABEL DEVICE_NAME " Identification";
    STYLE GROUP;
    ITEMS
    {   
        tag(DISPLAY_VALUE),
        longTag(DISPLAY_VALUE),
        descriptor (DISPLAY_VALUE),
        message (DISPLAY_VALUE),
        final_assembly_number (DISPLAY_VALUE),
        date (DISPLAY_VALUE),        
        country_code (DISPLAY_VALUE), 
        si_control (DISPLAY_VALUE),        
        deviceVariables[2].DIGITAL_UNITS (DISPLAY_VALUE)        
    }
}


MENU manual_setup_device_group2
{
    LABEL "Write Protect";
    STYLE GROUP;
    ITEMS
    {   
        write_protect_mode (DISPLAY_VALUE)                    
    }
}


MENU manual_setup_other_group1
{
    LABEL "Polling";
    STYLE GROUP;
    ITEMS
    {   
        polling_address (DISPLAY_VALUE),         
        COLUMNBREAK,
        "Set the HART address for the " DEVICE_NAME "\nwhen using the wired-HART interface"         
    }
}


MENU manual_setup_other_group2
{
    LABEL "HART Master";
    STYLE GROUP;
    ITEMS
    {   
        master_mode (DISPLAY_VALUE),
        retry_count (DISPLAY_VALUE),        
        COLUMNBREAK,        
        "Set the HART master mode for the " DEVICE_NAME "\nwhen communicated with wired devices\n\nSet the number of retries the " DEVICE_NAME " will\nperform for wired communications"       
    }
}


MENU manual_setup_4_20_ma
{
    LABEL "4-20 mA";
    STYLE PAGE;
    ITEMS
    {
        manual_setup_4_20ma_group1   
    }
}


MENU manual_setup_4_20ma_group1
{
    LABEL "4-20 mA";
    STYLE GROUP;
    ITEMS
    {   
        PV.DEVICE_VARIABLE.DIGITAL_UNITS (DISPLAY_VALUE),
        PV.RANGING.TRANSFER_FUNCTION (DISPLAY_VALUE),
        PV.DEVICE_VARIABLE.DAMPING_VALUE (DISPLAY_VALUE),
        PV.RANGING.UPPER_RANGE_VALUE (DISPLAY_VALUE),
        PV.RANGING.LOWER_RANGE_VALUE (DISPLAY_VALUE),
        var0_fault_current_upper (DISPLAY_VALUE),
        var0_prop_current_upper (DISPLAY_VALUE),
        var0_prop_current_lower (DISPLAY_VALUE),
        var0_fault_current_lower (DISPLAY_VALUE),
        pv_lookup_table,
        COLUMNBREAK,  
        "Set the PV Eng Units of the 4-20mA Field Device\n\nSet the 4-20mA Linearization Mode\n\n\nSet the Damping Factor for the PV\n\nOutput assigned to the 20mA Current input\n\n\nOutput assigned to the 4mA Current input\n\nMax current output by the 4-20mA Device when in fault condition\n\n\nUpper limit value of the proportional range\n\nLower limit value of the proportional range\n\n\nMin current output by the 4-20mA Device when in fault condition"    }
}


MENU status_display
{
    LABEL "Device Status";
    STYLE WINDOW;
    ITEMS
    {
        status_display_page
    }
}


MENU status_display_page
{
    LABEL "Device Status";
    STYLE PAGE;
    ITEMS
    {        
        device_status,
        standardized_status_2 (DISPLAY_VALUE),       
        COLUMNBREAK,
        extended_fld_device_status (DISPLAY_VALUE),
        standardized_status_3 (DISPLAY_VALUE),
        COLUMNBREAK,
        standardized_status_0 (DISPLAY_VALUE),
        device_specific_status_0 (DISPLAY_VALUE),       
        device_specific_status_1 (DISPLAY_VALUE), 
        config_change_counter (DISPLAY_VALUE)
    }
}


MENU time
{
    LABEL "Time";
    STYLE WINDOW; 
    ITEMS
    {
        time_page
    }
}

MENU time_page
{
    LABEL "Time";
    STYLE PAGE; 
    ITEMS
    {
        time_group1,
        time_group2
    }
}

MENU time_group1
{
    LABEL "Time";
    STYLE GROUP; 
    ITEMS
    {
        current_date(DISPLAY_VALUE),
        current_time1(DISPLAY_VALUE)
    }
}


MENU time_group2
{
    LABEL "Uptime";
    STYLE GROUP; 
    ITEMS
    {
        system_uptime(DISPLAY_VALUE)
    }
}


MENU power_time
{
    LABEL "Power";
    STYLE WINDOW; 
    ITEMS
    {
        power_time_page
    }
}

MENU power_time_page
{
    LABEL "Power";
    STYLE PAGE; 
    ITEMS
    {
        manual_setup_power_status_group1,
        manual_setup_power_status_group2        
        COLUMNBREAK,
        manual_setup_power_status_group3,
        manual_setup_power_status_group4                        
    }
}


MENU wireless_status_dlg
{
    LABEL "Wireless Status";
    STYLE DIALOG;
    ITEMS
    {
        wireless_status,
        wireless_statistics        
    }
}

MENU wireless_status
{
    LABEL "Wireless Status";
    STYLE PAGE;
    ITEMS
    {
        wireless_status_group1,
        wireless_status_group2,
        COLUMNBREAK,
        wireless_status_group3        
    }
}

MENU wireless_status_group1
{
    LABEL "Join Details";
    STYLE GROUP;
    ITEMS
    {
        wireless_mode (DISPLAY_VALUE),
        join_mode (DISPLAY_VALUE, READ_ONLY),          
        wireless_duty_cycle(DISPLAY_VALUE),
        last_join_time(DISPLAY_VALUE),
        advertisements (DISPLAY_VALUE),
        neighbor_count (DISPLAY_VALUE),
        join_attempts (DISPLAY_VALUE)
    }
}


MENU wireless_status_group2
{
    LABEL "Burst Service Status";
    STYLE GROUP;
    ITEMS
    {
        burst_service_requested (DISPLAY_VALUE),
        burst_service_granted (DISPLAY_VALUE)     
    }
}

MENU wireless_status_group3
{
    LABEL "Join Status";
    STYLE GROUP;
    ITEMS
    {
        join_status[0x0001] (DISPLAY_VALUE),        
        join_status[0x0004] (DISPLAY_VALUE),
        join_status[0x0008] (DISPLAY_VALUE),
        join_status[0x0010] (DISPLAY_VALUE),
        join_status[0x0020] (DISPLAY_VALUE),
        join_status[0x0040] (DISPLAY_VALUE),
        join_status[0x0080] (DISPLAY_VALUE),
        join_status[0x0100] (DISPLAY_VALUE),
        join_status[0x0200] (DISPLAY_VALUE),
        join_status[0x0400] (DISPLAY_VALUE)
    }
}


MENU wireless_statistics
{
    LABEL "Wireless Statistics";
    STYLE PAGE;
    ITEMS
    {
        wireless_statistics_group
    }
}


MENU wireless_statistics_group
{
    LABEL "Wireless Statistics";
    STYLE GROUP;
    ITEMS
    {
        generated_packets (DISPLAY_VALUE),
        terminated_packets (DISPLAY_VALUE),
        detected_crc_errors (DISPLAY_VALUE),
        detected_dll_mic_failures (DISPLAY_VALUE),
        detected_nl_mic_failures (DISPLAY_VALUE),
        not_received_nonce_counter_values (DISPLAY_VALUE)
    }
}


MENU message_statistics
{
    LABEL "Wired Statistics";
    STYLE PAGE;
    ITEMS
    {
       AdapterStats,                 // menu
       COLUMNBREAK,
       message_statistics_master           
    }
}


MENU AdapterStats
{
    LABEL "Wired Slave Statistics";
    STYLE GROUP;
    ITEMS
    {
       STX_count(DISPLAY_VALUE),
       ACK_count(DISPLAY_VALUE),
       BACK_count(DISPLAY_VALUE)
    }
}


MENU message_statistics_master
{
    LABEL "Wired Master Statistics";
    STYLE GROUP;
    ITEMS
    {
       io_channel_stx_sent(DISPLAY_VALUE),
       io_channel_ack_received(DISPLAY_VALUE),
       io_channel_ostx_received(DISPLAY_VALUE),
       io_channel_oack_received(DISPLAY_VALUE),
       io_channel_back_received(DISPLAY_VALUE),       
       io_channel_parity_err_received(DISPLAY_VALUE),
       io_channel_framing_err_received(DISPLAY_VALUE),
       io_channel_checkbyte_err_received(DISPLAY_VALUE),
       io_channel_gap_err_received(DISPLAY_VALUE)       
    }
}


MENU root_menu
{
    LABEL "Online";
    ITEMS
    {
        overview_tree,               // menu 
        configure_tree,              // menu 
        service_tools_tree           // menu 
    }
}


MENU overview_tree
{
    LABEL "Overview";    
    ITEMS
    {   
        alerts,
        wireless_mode (DISPLAY_VALUE),
        PV.DAQ.ANALOG_VALUE(DISPLAY_VALUE),
        PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),        
        var1_value(DISPLAY_VALUE, READ_ONLY),        
        var2_value(DISPLAY_VALUE, READ_ONLY),          
        subdevice_info_tree1,
        subdevice_info_tree2,
        subdevice_info_tree3,
        subdevice_info_tree4,
        subdevice_info_tree5,
        subdevice_info_tree6,
        subdevice_info_tree7,
        subdevice_info_tree8                      
    }
}


MENU device_info_main_tree
{
    LABEL "Device Information";
    ITEMS
    {
        tag (DISPLAY_VALUE),
        longTag(DISPLAY_VALUE),   
        device_info_tree,
        wireless_info_tree
    }
}


MENU device_info_tree
{
    LABEL "Device";
    ITEMS
    {
        manufacturer_id (DISPLAY_VALUE, READ_ONLY),
        device_type (DISPLAY_VALUE, READ_ONLY),
        device_mac_address(DISPLAY_VALUE, READ_ONLY),         
        device_serial_num(DISPLAY_VALUE, READ_ONLY),
        device_model_num(DISPLAY_VALUE,READ_ONLY),
        device_build_date(DISPLAY_VALUE, READ_ONLY),
        device_lot_num(DISPLAY_VALUE, READ_ONLY)   
        device_id (DISPLAY_VALUE, READ_ONLY),
        universal_revision (DISPLAY_VALUE, READ_ONLY),        
        transmitter_revision (DISPLAY_VALUE, READ_ONLY),
        hardware_revision (DISPLAY_VALUE, READ_ONLY),        
        software_revision (DISPLAY_VALUE, READ_ONLY),      
        software_revision_internal (DISPLAY_VALUE, READ_ONLY),
        software_bootloader_revision (DISPLAY_VALUE, READ_ONLY),
        software_build_date(DISPLAY_VALUE, READ_ONLY)
        device_description_version2 (DISPLAY_VALUE, READ_ONLY)
        final_assembly_number (DISPLAY_VALUE),
        date (DISPLAY_VALUE),
        descriptor (DISPLAY_VALUE),
        message (DISPLAY_VALUE),                   
        country_code (DISPLAY_VALUE),
        si_control (DISPLAY_VALUE),        
        deviceVariables[2].DIGITAL_UNITS (DISPLAY_VALUE),            
        write_protect_mode (DISPLAY_VALUE)
    }
}


EDIT_DISPLAY pv_lookup_table
{
    LABEL "PV Linearization Table";
    DISPLAY_ITEMS
    {
        pv_lookup_ma_value1,
        pv_lookup_eng_value1, 
        pv_lookup_ma_value2,
        pv_lookup_eng_value2,
        pv_lookup_ma_value3,
        pv_lookup_eng_value3,
        pv_lookup_ma_value4,
        pv_lookup_eng_value4,
        pv_lookup_ma_value5,
        pv_lookup_eng_value5,
        pv_lookup_ma_value6,
        pv_lookup_eng_value6,
        pv_lookup_ma_value7,
        pv_lookup_eng_value7,
        pv_lookup_ma_value8,
        pv_lookup_eng_value8,
        pv_lookup_ma_value9,
        pv_lookup_eng_value9,
        pv_lookup_ma_value10,
        pv_lookup_eng_value10,
        pv_lookup_ma_value11,
        pv_lookup_eng_value11,
        pv_lookup_ma_value12,
        pv_lookup_eng_value12,
        pv_lookup_ma_value13,
        pv_lookup_eng_value13,
        pv_lookup_ma_value14,
        pv_lookup_eng_value14,
        pv_lookup_ma_value15,
        pv_lookup_eng_value15,
        pv_lookup_ma_value16,
        pv_lookup_eng_value16,
        pv_lookup_ma_value17,
        pv_lookup_eng_value17,
        pv_lookup_ma_value18,
        pv_lookup_eng_value18,
        pv_lookup_ma_value19,
        pv_lookup_eng_value19,
        pv_lookup_ma_value20,
        pv_lookup_eng_value20,
        pv_lookup_ma_value21,
        pv_lookup_eng_value21,
        pv_lookup_ma_value22,
        pv_lookup_eng_value22,
        pv_lookup_ma_value23,
        pv_lookup_eng_value23,
        pv_lookup_ma_value24,
        pv_lookup_eng_value24,
        pv_lookup_ma_value25,
        pv_lookup_eng_value25,
        pv_lookup_ma_value26,
        pv_lookup_eng_value26,
        pv_lookup_ma_value27,
        pv_lookup_eng_value27,
        pv_lookup_ma_value28,
        pv_lookup_eng_value28,
        pv_lookup_ma_value29,
        pv_lookup_eng_value29,
        pv_lookup_ma_value30,
        pv_lookup_eng_value30,
        pv_lookup_ma_value31,
        pv_lookup_eng_value31,
        pv_lookup_ma_value32,
        pv_lookup_eng_value32
    }
    EDIT_ITEMS 
    { 
        pv_lookup1,
        pv_lookup2,
        pv_lookup3,
        pv_lookup4,
        pv_lookup5,
        pv_lookup6,
        pv_lookup7,
        pv_lookup8,
        pv_lookup9,
        pv_lookup10,
        pv_lookup11,
        pv_lookup12,
        pv_lookup13,
        pv_lookup14,
        pv_lookup15,
        pv_lookup16,
        pv_lookup17,
        pv_lookup18,
        pv_lookup19,
        pv_lookup20,
        pv_lookup21,
        pv_lookup22,
        pv_lookup23,
        pv_lookup24,
        pv_lookup25,
        pv_lookup26,
        pv_lookup27,
        pv_lookup28,
        pv_lookup29,
        pv_lookup30,
        pv_lookup31,
        pv_lookup32
    }
}


MENU wireless_info_tree
{
    LABEL "Wireless";
    ITEMS
    {
        wireless_module_manufacturer_id(DISPLAY_VALUE),        
        wireless_module_device_type(DISPLAY_VALUE),            
        wireless_module_transmitter_revision(DISPLAY_VALUE),            
        wireless_module_software_revision(DISPLAY_VALUE),
        wireless_module_hardware_revision(DISPLAY_VALUE) 
        dust_software_major(DISPLAY_VALUE),
        dust_software_minor(DISPLAY_VALUE),
        dust_software_patch(DISPLAY_VALUE),
        dust_software_build(DISPLAY_VALUE)  
    }
}


MENU configure_tree
{
    LABEL "Configure";    
    ITEMS
    {
        guided_setup_tree,           // menu 
        manual_setup_tree            // menu 
    }
}


MENU service_tools_tree
{
    LABEL "Service Tools";
    ITEMS
    {           
        alerts_tree,        
        status_display_tree,     
        power_time_tree,
        communications_tree,
        maintenance_tree,
        time_tree,            
        simulate_tree           
    }
}


MENU status_display_tree
{
    LABEL "Device Status";    
    ITEMS
    {
        device_status (DISPLAY_VALUE),
        standardized_status_2 (DISPLAY_VALUE),               
        extended_fld_device_status (DISPLAY_VALUE),
        standardized_status_3 (DISPLAY_VALUE),        
        standardized_status_0 (DISPLAY_VALUE),
        device_specific_status_0 (DISPLAY_VALUE),       
        device_specific_status_1 (DISPLAY_VALUE),       
        config_change_counter (DISPLAY_VALUE)
    }
}


MENU power_time_tree
{
    LABEL "Power";    
    ITEMS
    {   
        loop_power_mode (DISPLAY_VALUE, READ_ONLY),     
        loop_turn_on_time (DISPLAY_VALUE, READ_ONLY),                
        loop_idle_time(DISPLAY_VALUE,READ_ONLY),
        loop_connect_estimated_percent(DISPLAY_VALUE),
        loop_connect_on_time(DISPLAY_VALUE),
        loop_connect_off_time(DISPLAY_VALUE),
        loop_connect_on_percent(DISPLAY_VALUE)        
        power_battery_tree        
    }
}

MENU power_battery_tree
{
    LABEL "External Battery";    
    VALIDITY  IF ( hardware_revision >= 2 )   {TRUE;}   ELSE  {FALSE;}    
    ITEMS
    {   
        battery_capacity(DISPLAY_VALUE, READ_ONLY),
        battery_low_voltage(DISPLAY_VALUE, READ_ONLY),
        battery_critical_voltage(DISPLAY_VALUE, READ_ONLY),
        device_power_status (DISPLAY_VALUE, READ_ONLY),     
        battery_life (DISPLAY_VALUE, READ_ONLY),                
        battery_coulomb_curr_rate(DISPLAY_VALUE,READ_ONLY),
        battery_coulomb_total(DISPLAY_VALUE,READ_ONLY),
        battery_coulomb_remain(DISPLAY_VALUE,READ_ONLY),
        battery_change_date(DISPLAY_VALUE,READ_ONLY)
    }
}


MENU simulate_tree
{
    LABEL "Simluate";
    ITEMS
    {
        device_simulate_loop_current
        device_simulate_direct_power, 
        device_simulate_temperature
    }
}



MENU time_tree
{
    LABEL "Time";
    ITEMS
    {
        current_date(DISPLAY_VALUE),
        current_time1(DISPLAY_VALUE),
        system_uptime(DISPLAY_VALUE)
    }
}


MENU maintenance_tree
{
    LABEL "Maintenance";
    ITEMS
    {
        device_master_reset,
        device_self_test,
        factoryResetMethod,
        active_advertising,
        adapter_loop_cal,
        var3_value(DISPLAY_VALUE)
    }
}


MENU communications_tree
{
    LABEL "Communications";
    ITEMS
    {
        wireless_status_tree,             
        wireless_statistics_tree,
        message_statistics_tree,
        message_statistics_tree1
    }
}


MENU wireless_status_tree
{
    LABEL "Wireless Status";    
    ITEMS
    {
        wireless_mode (DISPLAY_VALUE),
        join_status(DISPLAY_VALUE),   
        join_mode (DISPLAY_VALUE, READ_ONLY),          
        wireless_duty_cycle(DISPLAY_VALUE),
        last_join_time(DISPLAY_VALUE),
        advertisements (DISPLAY_VALUE),
        neighbor_count (DISPLAY_VALUE),
        join_attempts (DISPLAY_VALUE),
        burst_service_requested (DISPLAY_VALUE),
        burst_service_granted (DISPLAY_VALUE)   

    }
}


MENU wireless_statistics_tree
{
    LABEL "Wireless Statistics";    
    ITEMS
    {
        generated_packets (DISPLAY_VALUE),
        terminated_packets (DISPLAY_VALUE),
        detected_crc_errors (DISPLAY_VALUE),
        detected_dll_mic_failures (DISPLAY_VALUE),
        detected_nl_mic_failures (DISPLAY_VALUE),
        not_received_nonce_counter_values (DISPLAY_VALUE)
    }
}


MENU message_statistics_tree
{
    LABEL "Wired Slave Statistics";
    ITEMS
    {
       STX_count(DISPLAY_VALUE),
       ACK_count(DISPLAY_VALUE),
       BACK_count(DISPLAY_VALUE)
    }
}


MENU message_statistics_tree1
{
    LABEL "Wired Master Statistics";
    ITEMS
    {
       io_channel_stx_sent(DISPLAY_VALUE),
       io_channel_ack_received(DISPLAY_VALUE),
       io_channel_ostx_received(DISPLAY_VALUE),
       io_channel_oack_received(DISPLAY_VALUE),
       io_channel_back_received(DISPLAY_VALUE)       
       io_channel_parity_err_received(DISPLAY_VALUE),
       io_channel_framing_err_received(DISPLAY_VALUE),
       io_channel_checkbyte_err_received(DISPLAY_VALUE),
       io_channel_gap_err_received(DISPLAY_VALUE)       
    }
}


MENU guided_setup_tree
{
    LABEL "Guided Setup";
    ITEMS
    {
        adapter_config_power,   // method  
        join_network
    }
}


MENU manual_setup_tree
{
    LABEL "Manual Setup";
    ITEMS
    {
        manual_setup_power_tree,
        manual_setup_wireless_tree,           
        manual_setup_wired_tree        
        manual_setup_4_20_ma_tree,
        manual_setup_burst_tree,
        manual_setup_event_tree,           
        device_info_main_tree
    }
}


MENU manual_setup_power_tree
{
    LABEL "Power";
    ITEMS
    {
        adapter_config_power,
        adapter_power (DISPLAY_VALUE), 
        loop_power_mode (DISPLAY_VALUE), 
        manual_setup_power_tree1        
        manual_setup_power_tree2        
    }
}


MENU manual_setup_power_tree1
{
    LABEL "Power Control Settings";
    VALIDITY  IF ( ( license_key_power & 0x0300 ) == 0x0300 )   {TRUE;}   ELSE  {FALSE;}    
    ITEMS
    {           
        loop_turn_on_time (DISPLAY_VALUE),                
        loop_idle_time(DISPLAY_VALUE),
        loop_connect_estimated_percent(DISPLAY_VALUE),
        loop_switch_cutoff_en(DISPLAY_VALUE),
        loop_switch_cutoff_voltage(DISPLAY_VALUE)

    }
}

MENU manual_setup_power_tree2
{
    LABEL "External Battery Settings";    
    VALIDITY  IF ( hardware_revision >= 2 )   {TRUE;}   ELSE  {FALSE;}    
    ITEMS
    {           
        battery_capacity(DISPLAY_VALUE),
        battery_low_voltage(DISPLAY_VALUE),
        battery_critical_voltage(DISPLAY_VALUE),
        clear_battery_counters
    }
}


MENU manual_setup_wireless_tree
{
    LABEL "Wireless";    
    ITEMS
    {
        join_network,
        disconnect_network,
        network_id (DISPLAY_VALUE),            
        join_mode (DISPLAY_VALUE), 
        radio_power_output1 (DISPLAY_VALUE), 
        dust_otap_setting (DISPLAY_VALUE)
    }
}


MENU manual_setup_wired_tree
{
    LABEL "Wired";    
    ITEMS
    {
        master_mode (DISPLAY_VALUE),
        retry_count (DISPLAY_VALUE),  
        polling_address (DISPLAY_VALUE), 
        sub_device_time_sync_en(DISPLAY_VALUE), 
        sub_device_powerUp_scan (DISPLAY_VALUE),
        poll_addr_start(DISPLAY_VALUE),
        poll_addr_stop(DISPLAY_VALUE),  
        scan_subdevices
    }
}


MENU manual_setup_4_20_ma_tree
{
    LABEL "4-20 mA";
    ITEMS
    {
        PV.DEVICE_VARIABLE.DIGITAL_UNITS (DISPLAY_VALUE),
        PV.RANGING.TRANSFER_FUNCTION (DISPLAY_VALUE),
        PV.DEVICE_VARIABLE.DAMPING_VALUE (DISPLAY_VALUE),
        PV.RANGING.UPPER_RANGE_VALUE (DISPLAY_VALUE),
        PV.RANGING.LOWER_RANGE_VALUE (DISPLAY_VALUE),
        var0_fault_current_upper (DISPLAY_VALUE),
        var0_prop_current_upper (DISPLAY_VALUE),
        var0_prop_current_lower (DISPLAY_VALUE),
        var0_fault_current_lower (DISPLAY_VALUE),
        pv_lookup_table
    }
}


MENU manual_setup_burst_tree
{
    LABEL "Burst Settings";
    ITEMS
    {
        auto_burst_mode (DISPLAY_VALUE), 
        auto_burst_type (DISPLAY_VALUE),
        burst_menu_tree_0,
        burst_menu_tree_1,
        burst_menu_tree_2,
        burst_menu_tree_3,
        burst_menu_tree_4,
        burst_menu_tree_5,        
        burst_menu_tree_6,
        burst_menu_tree_7,
        burst_menu_tree_8,
        burst_menu_tree_9,
        burst_menu_tree_10,
        burst_menu_tree_11,
        burst_menu_tree_12,
        burst_menu_tree_13,
        burst_menu_tree_14,
        burst_menu_tree_15,
        burst_menu_tree_16,
        burst_menu_tree_17  
    }
}


MENU manual_setup_event_tree
{
    LABEL "Event Settings";
    ITEMS
    {             
        event_menu_tree_0,
        event_menu_tree_1
        event_menu_tree_2,
        event_menu_tree_3,
        event_menu_tree_4,       
        event_menu_tree_5,
        event_menu_tree_6,
        event_menu_tree_7,
        event_menu_tree_8   
    }
}


METHOD adapter_loop_cal
{
    LABEL "Loop Current Calibration";
    HELP "Loop Current Calibration";
/*  APPHELP "This type of calibration is usually used to compensate for"
            " drifting or aging output electronics"; */
    DEFINITION
    {
        char status[STATUS_SIZE];
        char disp_string1[60];
        char disp_string2[60];
        long var_id[1];
        int retry;
        int slen1;
        int slen2;
        float fOffset;

        slen1 = 60;
        slen2 = 60;

        IGNORE_ALL_DEVICE_STATUS();
        IGNORE_ALL_RESPONSE_CODES();
        XMTR_IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_RESPONSE_CODES();

        get_dictionary_string(remove_loop_from_auto, disp_string1, slen1);
        ACKNOWLEDGE(disp_string1);
        add_abort_method(return_to_normal);
        
        ACKNOWLEDGE("Connect current source to Adapter");   
        ACKNOWLEDGE("Set current source to 4.0mA");

        assign_float(PV.DAQ.ANALOG_VALUE,4.0);
        send(40, status);

        if (status[STATUS_RESPONSE_CODE])
        {
            display_response_status(40,status[STATUS_RESPONSE_CODE]);
            get_dictionary_string(abort_last_error, disp_string1, slen1);
            DELAY(2, disp_string1);
            process_abort();
        }

        remove_abort_method(return_to_normal);
        add_abort_method(leave_fixed_current_mode);

        var_id[0] = VARID(PV.DAQ.ANALOG_VALUE);
        fOffset = var1_value;
        fOffset *= 0.002;

        do
        {      
            GET_DEV_VAR_VALUE("Enter exact current source value", PV.DAQ.ANALOG_VALUE);

            PV.DAQ.ANALOG_VALUE += fOffset;           

            send(45, status);

            assign_float(PV.DAQ.ANALOG_VALUE, 4.0);  /*Put the previous value back */

            

            if (( status[STATUS_RESPONSE_CODE] == 3) || (status[STATUS_RESPONSE_CODE] == 4))
            {
                display_response_status(45, status[STATUS_RESPONSE_CODE]);
                retry = 1;
            }
            else if (status[STATUS_RESPONSE_CODE])
            {
                display_response_status(45, status[STATUS_RESPONSE_CODE]);
                get_dictionary_string(abort_last_error, disp_string1, slen1);
                DELAY(2, disp_string1);
                process_abort();
            }
            else
            {
                get_dictionary_string(fld_dev_otpt_equal_ref_meter, disp_string1, slen1);
                get_dictionary_string(yes_no, disp_string2, slen2);
                retry = select_from_list(disp_string1, var_id, disp_string2);
            }
        } while (retry);
        
        ACKNOWLEDGE("Set current source to 20.0mA");

        assign_float(PV.DAQ.ANALOG_VALUE, 20.0);

        send(40, status);

        if ( status[STATUS_RESPONSE_CODE])
        {
            display_response_status(40, status[STATUS_RESPONSE_CODE]);
            get_dictionary_string(abort_last_error, disp_string1, slen1);
            DELAY(2, disp_string1);
            process_abort();
        }

        do
        {            
            GET_DEV_VAR_VALUE("Enter exact current source value", PV.DAQ.ANALOG_VALUE);
            PV.DAQ.ANALOG_VALUE += fOffset;  

            send(46,status);

            assign_float(PV.DAQ.ANALOG_VALUE, 20.0);  /*Put the previous value back */

            if ((status[STATUS_RESPONSE_CODE] == 3 ) || (status[STATUS_RESPONSE_CODE] == 4))
            {
                display_response_status(46, status[STATUS_RESPONSE_CODE]);
                retry = 1;
            }
            else if ( status[STATUS_RESPONSE_CODE])
            {
                display_response_status(46, status[STATUS_RESPONSE_CODE]);
                get_dictionary_string(abort_last_error, disp_string1, slen1);
                DELAY(2, disp_string1);
                process_abort();
            }
            else
            {
                get_dictionary_string(fld_dev_otpt_equal_ref_meter, disp_string1, slen1);
                get_dictionary_string(yes_no, disp_string2, slen2);
                retry = select_from_list(disp_string1, var_id, disp_string2);
            }
        } while (retry);

        process_abort() ;
    }
}

